@@ -39,23 +39,20 @@
 #include <config.h>
 #endif
 
-#include "sysstuff.h"
 #include "typedefs.h"
 #include "macros.h"
 #include "gromacs/utility/smalloc.h"
-#include "mshift.h"
 #include "gromacs/commandline/pargs.h"
 #include "copyrite.h"
 #include "gromacs/fileio/pdbio.h"
-#include "gmx_fatal.h"
-#include "xvgr.h"
-#include "gromacs/fileio/matio.h"
-#include "index.h"
+#include "gromacs/utility/fatalerror.h"
+#include "gromacs/fileio/xvgr.h"
+#include "gromacs/topology/index.h"
 #include "gstat.h"
 #include "gromacs/fileio/tpxio.h"
 #include "viewit.h"
 #include "gbutil.h"
-#include "vec.h"
+#include "gromacs/math/vec.h"
 #include "gromacs/fileio/confio.h"
 #include "gromacs/fileio/gmxfio.h"
 
@@ -226,7 +223,7 @@ int main(int argc,char *argv[])
 #define NFILE asize(fnm)
     
     CopyRight(stderr,argv[0]);
-    parse_common_args(&argc,argv,PCA_CAN_TIME | PCA_CAN_VIEW | PCA_TIME_UNIT | PCA_BE_NICE ,
+    parse_common_args(&argc,argv,PCA_CAN_TIME | PCA_CAN_VIEW | PCA_TIME_UNIT,
 		      NFILE,fnm, asize(pa),pa, asize(desc),desc,
 		      asize(bugs),bugs,&oenv
 	);
@@ -350,9 +347,6 @@ int main(int argc,char *argv[])
 		out=gmx_ffopen(TrjoutFile,filemode);
 		break;
 	}
-	if (outftp == efG87)
-	    fprintf(gmx_fio_getfp(trx_get_fileio(trxout)),"Generated by %s. #atoms=%d, a BOX is"
-		    " stored in this file.\n",ShortProgram(),nout);
     }
     
     if (natoms > atoms->nr) {
