@@ -37,7 +37,7 @@
 #include "typedefs.h"
 #include "macros.h"
 #include "gromacs/utility/smalloc.h"
-#include "xvgr.h"
+#include "gromacs/fileio/xvgr.h"
 #include "complex.h"
 #include "fftgrid.h"
 #include "mdrun.h"
