@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2010,2011,2012,2013, by the GROMACS development team, led by
+ * Copyright (c) 2010,2011,2012,2013,2014, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -43,8 +43,6 @@
 #ifndef GMX_ANALYSISDATA_DATAMODULE_H
 #define GMX_ANALYSISDATA_DATAMODULE_H
 
-#include "../legacyheaders/types/simple.h"
-
 namespace gmx
 {
 
@@ -62,20 +60,8 @@ class AnalysisDataPointSetRef;
  * parallelDataStarted() methods (see below).
  * All other methods in the interface are callbacks that are called by the
  * data object to which the module is attached to describe the data.
- *
- * The modules can operate in two modes: serial or parallel.
- * In serial mode, the frames are presented to the module always in the order
- * of increasing indices, even if they become ready in a different order in the
- * attached data.
- * In parallel mode, the frames are presented in the order that they become
- * available in the input data, which may not be sequential.  This mode allows
- * the input data to optimize its behavior if it does not need to store and
- * sort the frames.
- * If the input data supports parallel mode, it calls parallelDataStarted().
- * If the module returns true from this method, then it will process the frames
- * in the parallel mode.  If the module returns false, it will get the frames
- * in serial order.
- * If the input data does not support parallel mode, it calls dataStarted().
+ * See \ref module_analysisdata for an overview of the notifications the
+ * modules receive, and \ref page_analysisdata for overview of the terminology.
  *
  * Concrete modules typically do not directly derive from this interface, but
  * from either AnalysisDataModuleSerial or AnalysisDataModuleParallel.
@@ -217,6 +203,21 @@ class AnalysisDataModuleInterface
          *      implementing class to report errors.
          */
         virtual void frameFinished(const AnalysisDataFrameHeader &header) = 0;
+        /*! \brief
+         * Called in sequential order for each frame after they are finished.
+         *
+         * \param[in] frameIndex   Index of the next finished frame.
+         * \throws    unspecified  Can throw any exception required by the
+         *      implementing class to report errors.
+         *
+         * This method is called after frameFinished(), but with an additional
+         * constraint that it is always called in serial and with an increasing
+         * \p frameIndex.  Parallel data modules need this to serialize their
+         * data for downsteam serial modules; AnalysisDataModuleSerial provides
+         * an empty implementation, as there frameFinished() can be used for
+         * the same purpose.
+         */
+        virtual void frameFinishedSerial(int frameIndex) = 0;
         /*! \brief
          * Called (once) when no more data is available.
          *
@@ -253,6 +254,7 @@ class AnalysisDataModuleSerial : public AnalysisDataModuleInterface
         virtual bool parallelDataStarted(
             AbstractAnalysisData              *data,
             const AnalysisDataParallelOptions &options);
+        virtual void frameFinishedSerial(int /*frameIndex*/) {}
 };
 
 /*! \brief
@@ -278,7 +280,8 @@ class AnalysisDataModuleParallel : public AnalysisDataModuleInterface
         virtual void frameStarted(const AnalysisDataFrameHeader &frame)   = 0;
         virtual void pointsAdded(const AnalysisDataPointSetRef &points)   = 0;
         virtual void frameFinished(const AnalysisDataFrameHeader &header) = 0;
-        virtual void dataFinished() = 0;
+        virtual void frameFinishedSerial(int index) = 0;
+        virtual void dataFinished()                 = 0;
 
     private:
         virtual void dataStarted(AbstractAnalysisData *data);
