@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2013,2014, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2015, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -39,11 +39,14 @@
  * \author Teemu Murtola <teemu.murtola@gmail.com>
  * \ingroup module_commandline
  */
+#include "gmxpre.h"
+
 #include "cmdlinehelpcontext.h"
 
-#include "gromacs/commandline/shellcompletions.h"
 #include "gromacs/utility/gmxassert.h"
 
+#include "shellcompletions.h"
+
 namespace gmx
 {
 
@@ -94,9 +97,11 @@ class CommandLineHelpContext::Impl
 };
 
 CommandLineHelpContext::CommandLineHelpContext(
-        File *file, HelpOutputFormat format, const HelpLinks *links)
+        File *file, HelpOutputFormat format, const HelpLinks *links,
+        const std::string &programName)
     : impl_(new Impl(file, format, links))
 {
+    impl_->writerContext_.setReplacement("[PROGRAM]", programName);
 }
 
 CommandLineHelpContext::CommandLineHelpContext(
@@ -133,6 +138,11 @@ void CommandLineHelpContext::setShowHidden(bool bHidden)
     impl_->bHidden_ = bHidden;
 }
 
+void CommandLineHelpContext::enterSubSection(const std::string &title)
+{
+    impl_->writerContext_.enterSubSection(title);
+}
+
 const HelpWriterContext &CommandLineHelpContext::writerContext() const
 {
     return impl_->writerContext_;
