@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2010,2011,2012,2013,2014, by the GROMACS development team, led by
+ * Copyright (c) 2010,2011,2012,2013,2014,2015, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -39,6 +39,8 @@
  * \author Teemu Murtola <teemu.murtola@gmail.com>
  * \ingroup module_commandline
  */
+#include "gmxpre.h"
+
 #include "cmdlinehelpwriter.h"
 
 #include <cstring>
@@ -49,8 +51,6 @@
 #include <boost/scoped_ptr.hpp>
 
 #include "gromacs/commandline/cmdlinehelpcontext.h"
-#include "gromacs/commandline/shellcompletions.h"
-#include "gromacs/onlinehelp/helpformat.h"
 #include "gromacs/onlinehelp/helpwritercontext.h"
 #include "gromacs/options/basicoptions.h"
 #include "gromacs/options/filenameoption.h"
@@ -62,6 +62,8 @@
 #include "gromacs/utility/file.h"
 #include "gromacs/utility/stringutil.h"
 
+#include "shellcompletions.h"
+
 namespace gmx
 {
 
@@ -171,7 +173,9 @@ class OptionsFilter : public OptionsVisitor
         //! Specifies the type of output that formatSelected() produces.
         enum FilterType
         {
-            eSelectFileOptions,
+            eSelectInputFileOptions,
+            eSelectInputOutputFileOptions,
+            eSelectOutputFileOptions,
             eSelectOtherOptions
         };
 
@@ -230,9 +234,26 @@ void OptionsFilter::visitOption(const OptionInfo &option)
     {
         return;
     }
-    if (option.isType<FileNameOptionInfo>())
+    const FileNameOptionInfo *const fileOption = option.toType<FileNameOptionInfo>();
+    if (fileOption != NULL && fileOption->isInputFile())
     {
-        if (filterType_ == eSelectFileOptions)
+        if (filterType_ == eSelectInputFileOptions)
+        {
+            formatter_->formatOption(option);
+        }
+        return;
+    }
+    if (fileOption != NULL && fileOption->isInputOutputFile())
+    {
+        if (filterType_ == eSelectInputOutputFileOptions)
+        {
+            formatter_->formatOption(option);
+        }
+        return;
+    }
+    if (fileOption != NULL && fileOption->isOutputFile())
+    {
+        if (filterType_ == eSelectOutputFileOptions)
         {
             formatter_->formatOption(option);
         }
@@ -320,25 +341,17 @@ std::string
 fileOptionFlagsAsString(const FileNameOptionInfo &option, bool bAbbrev)
 {
     std::string type;
-    if (option.isInputOutputFile())
-    {
-        type = bAbbrev ? "In/Out" : "Input/Output";
-    }
-    else if (option.isInputFile())
-    {
-        type = "Input";
-    }
-    else if (option.isOutputFile())
-    {
-        type = "Output";
-    }
     if (!option.isRequired())
     {
-        type += bAbbrev ? ", Opt." : ", Optional";
+        type = bAbbrev ? "Opt." : "Optional";
     }
     if (option.isLibraryFile())
     {
-        type += bAbbrev ? ", Lib." : ", Library";
+        if (!type.empty())
+        {
+            type.append(", ");
+        }
+        type.append(bAbbrev ? "Lib." : "Library");
     }
     return type;
 }
@@ -374,7 +387,8 @@ class SynopsisFormatter : public OptionsFormatterInterface
     public:
         //! Creates a helper object for formatting the synopsis.
         explicit SynopsisFormatter(const HelpWriterContext &context)
-            : context_(context), lineLength_(0), indent_(0), currentLength_(0)
+            : context_(context), bFormatted_(false), lineLength_(0), indent_(0),
+              currentLength_(0)
         {
         }
 
@@ -387,6 +401,7 @@ class SynopsisFormatter : public OptionsFormatterInterface
 
     private:
         const HelpWriterContext &context_;
+        bool                     bFormatted_;
         int                      lineLength_;
         int                      indent_;
         int                      currentLength_;
@@ -405,13 +420,13 @@ void SynopsisFormatter::start(const char *name)
             lineLength_ = 78;
             file.writeString(name);
             break;
-        case eHelpOutputFormat_Man:
-            lineLength_ = 70;
-            file.writeString(name);
-            break;
-        case eHelpOutputFormat_Html:
-            lineLength_ = 78;
-            file.writeLine("<pre>");
+        case eHelpOutputFormat_Rst:
+            bFormatted_ = true;
+            lineLength_ = 74;
+            indent_    += 4;
+            file.writeLine(".. parsed-literal::");
+            file.writeLine();
+            file.writeString("    ");
             file.writeString(name);
             break;
         default:
@@ -423,10 +438,6 @@ void SynopsisFormatter::finish()
 {
     File &file = context_.outputFile();
     file.writeLine();
-    if (context_.outputFormat() == eHelpOutputFormat_Html)
-    {
-        file.writeLine("</pre>");
-    }
     file.writeLine();
 }
 
@@ -434,22 +445,18 @@ void SynopsisFormatter::formatOption(const OptionInfo &option)
 {
     std::string name, value;
     formatOptionNameAndValue(option, &name, &value);
-    std::string fullOptionText(" [-" + name);
+    int         totalLength = name.length() + 4;
+    std::string fullOptionText
+        = formatString(" [%s-%s", bFormatted_ ? ":strong:`" : "", name.c_str());
     if (!value.empty())
     {
-        fullOptionText.append(" ");
+        fullOptionText.append(bFormatted_ ? "` :emphasis:`" : " ");
         fullOptionText.append(value);
+        totalLength += value.length() + 1;
     }
-    fullOptionText.append("]");
-    const int   totalLength = fullOptionText.size();
+    fullOptionText.append(bFormatted_ ? "`]" : "]");
 
-    if (context_.outputFormat() == eHelpOutputFormat_Html)
-    {
-        value = replaceAll(value, "<", "&lt;");
-        value = replaceAll(value, ">", "&gt;");
-    }
-
-    File &file = context_.outputFile();
+    File       &file = context_.outputFile();
     currentLength_ += totalLength;
     if (currentLength_ >= lineLength_)
     {
@@ -505,6 +512,7 @@ class OptionsListFormatter : public OptionsFormatterInterface
                 if (header_ != NULL)
                 {
                     context_.writeTextBlock(header_);
+                    context_.writeTextBlock("");
                 }
                 context_.writeOptionListStart();
             }
@@ -513,7 +521,6 @@ class OptionsListFormatter : public OptionsFormatterInterface
 
         const HelpWriterContext               &context_;
         const CommonFormatterData             &common_;
-        boost::scoped_ptr<TextTableFormatter>  consoleFormatter_;
         const char                            *title_;
         const char                            *header_;
         bool                                   bDidOutput_;
@@ -528,63 +535,23 @@ OptionsListFormatter::OptionsListFormatter(
     : context_(context), common_(common),
       title_(title), header_(NULL), bDidOutput_(false)
 {
-    if (context.outputFormat() == eHelpOutputFormat_Console)
-    {
-        consoleFormatter_.reset(new TextTableFormatter());
-        consoleFormatter_->setFirstColumnIndent(1);
-        consoleFormatter_->setFoldLastColumnToNextLine(4);
-        consoleFormatter_->addColumn(NULL, 6, false);
-        consoleFormatter_->addColumn(NULL, 8, false);
-        consoleFormatter_->addColumn(NULL, 10, false);
-        consoleFormatter_->addColumn(NULL, 50, true);
-    }
 }
 
 void OptionsListFormatter::formatOption(const OptionInfo &option)
 {
     writeSectionStartIfNecessary();
-    std::string name, value;
+    std::string               name, value;
     formatOptionNameAndValue(option, &name, &value);
-    std::string defaultValue(defaultOptionValue(option));
-    std::string info;
-    if (!defaultValue.empty())
-    {
-        info = "(" + defaultValue + ")";
-    }
+    std::string               defaultValue(defaultOptionValue(option));
+    std::string               info;
     const FileNameOptionInfo *fileOption = option.toType<FileNameOptionInfo>();
     if (fileOption != NULL)
     {
         const bool bAbbrev = (context_.outputFormat() == eHelpOutputFormat_Console);
-        if (!info.empty())
-        {
-            info.append(" ");
-        }
-        info.append("(");
-        info.append(fileOptionFlagsAsString(*fileOption, bAbbrev));
-        info.append(")");
+        info = fileOptionFlagsAsString(*fileOption, bAbbrev);
     }
     std::string description(descriptionWithOptionDetails(common_, option));
-    if (context_.outputFormat() == eHelpOutputFormat_Console)
-    {
-        consoleFormatter_->clear();
-        consoleFormatter_->addColumnLine(0, "-" + name);
-        consoleFormatter_->addColumnLine(1, value);
-        if (!info.empty())
-        {
-            consoleFormatter_->addColumnLine(2, info);
-        }
-        consoleFormatter_->addColumnHelpTextBlock(3, context_, description);
-        context_.outputFile().writeString(consoleFormatter_->formatRow());
-    }
-    else
-    {
-        if (!info.empty())
-        {
-            value.append(" ");
-            value.append(info);
-        }
-        context_.writeOptionItem("-" + name, value, description);
-    }
+    context_.writeOptionItem("-" + name, value, defaultValue, info, description);
 }
 
 //! \}
@@ -632,34 +599,11 @@ void CommandLineHelpWriter::Impl::formatBugs(const HelpWriterContext &context)
         return;
     }
     context.writeTitle("Known Issues");
-    if (context.outputFormat() != eHelpOutputFormat_Console)
-    {
-        context.writeTextBlock("[UL]");
-    }
     ConstArrayRef<const char *>::const_iterator i;
     for (i = bugs_.begin(); i != bugs_.end(); ++i)
     {
-        const char *const bug = *i;
-        // TODO: The context should be able to do this also for console output, but
-        // that requires a lot more elaborate parser for the markup.
-        if (context.outputFormat() == eHelpOutputFormat_Console)
-        {
-            TextLineWrapperSettings settings;
-            settings.setIndent(2);
-            settings.setFirstLineIndent(0);
-            settings.setLineLength(78);
-            context.outputFile().writeLine(
-                    context.substituteMarkupAndWrapToString(
-                            settings, formatString("* %s", bug)));
-        }
-        else
-        {
-            context.writeTextBlock(formatString("[LI]%s", bug));
-        }
-    }
-    if (context.outputFormat() != eHelpOutputFormat_Console)
-    {
-        context.writeTextBlock("[ul]");
+        const char *const       bug = *i;
+        context.writeTextBlock(formatString("* %s", bug));
     }
 }
 
@@ -714,7 +658,11 @@ void CommandLineHelpWriter::writeHelp(const CommandLineHelpContext &context)
         writerContext.writeTitle("Synopsis");
         SynopsisFormatter synopsisFormatter(writerContext);
         synopsisFormatter.start(context.moduleDisplayName());
-        filter.formatSelected(OptionsFilter::eSelectFileOptions,
+        filter.formatSelected(OptionsFilter::eSelectInputFileOptions,
+                              &synopsisFormatter, impl_->options_);
+        filter.formatSelected(OptionsFilter::eSelectInputOutputFileOptions,
+                              &synopsisFormatter, impl_->options_);
+        filter.formatSelected(OptionsFilter::eSelectOutputFileOptions,
                               &synopsisFormatter, impl_->options_);
         filter.formatSelected(OptionsFilter::eSelectOtherOptions,
                               &synopsisFormatter, impl_->options_);
@@ -728,11 +676,19 @@ void CommandLineHelpWriter::writeHelp(const CommandLineHelpContext &context)
     }
     CommonFormatterData    common(impl_->timeUnit_.c_str());
     OptionsListFormatter   formatter(writerContext, common, "Options");
-    formatter.startSection("Options to specify input and output files:[PAR]");
-    filter.formatSelected(OptionsFilter::eSelectFileOptions,
+    formatter.startSection("Options to specify input files:");
+    filter.formatSelected(OptionsFilter::eSelectInputFileOptions,
                           &formatter, impl_->options_);
     formatter.finishSection();
-    formatter.startSection("Other options:[PAR]");
+    formatter.startSection("Options to specify input/output files:");
+    filter.formatSelected(OptionsFilter::eSelectInputOutputFileOptions,
+                          &formatter, impl_->options_);
+    formatter.finishSection();
+    formatter.startSection("Options to specify output files:");
+    filter.formatSelected(OptionsFilter::eSelectOutputFileOptions,
+                          &formatter, impl_->options_);
+    formatter.finishSection();
+    formatter.startSection("Other options:");
     filter.formatSelected(OptionsFilter::eSelectOtherOptions,
                           &formatter, impl_->options_);
     formatter.finishSection();
