@@ -2,8 +2,8 @@
  * This file is part of the GROMACS molecular simulation package.
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
- * Copyright (c) 2001-2004, The GROMACS development team,
- * Copyright (c) 2013, by the GROMACS development team, led by
+ * Copyright (c) 2001-2004, The GROMACS development team.
+ * Copyright (c) 2013,2014,2015, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -34,19 +34,19 @@
  * To help us fund GROMACS development, we humbly ask that you cite
  * the research papers on the package. Check out http://www.gromacs.org.
  */
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "gmxpre.h"
+
+#include "config.h"
 
 #ifdef GMX_INTERNAL_XDR
 
 
-#include <stdlib.h>
-#include <limits.h>
-#include <string.h>
-
 #include "gmx_system_xdr.h"
 
+#include <limits.h>
+#include <stdlib.h>
+#include <string.h>
+
 
 /* NB - THIS FILE IS ONLY USED ON MICROSOFT WINDOWS, since that
  * system doesn't provide any standard XDR system libraries. It will
@@ -579,7 +579,7 @@ double *dp;
             printf("Error when detecting floating-point word order.\n"
                    "Do you have a non-IEEE system?\n"
                    "If possible, use the XDR libraries provided with your system,\n"
-                   "instead of the Gromacs fallback XDR source.\n");
+                   "instead of the GROMACS fallback XDR source.\n");
             exit(0);
         }
     }
