@@ -2,8 +2,8 @@
  * This file is part of the GROMACS molecular simulation package.
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
- * Copyright (c) 2001-2004, The GROMACS development team,
- * Copyright (c) 2013, by the GROMACS development team, led by
+ * Copyright (c) 2001-2004, The GROMACS development team.
+ * Copyright (c) 2013,2014, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -39,8 +39,11 @@
 #define GMX_FILEIO_GMXFIO_H
 
 #include <stdio.h>
-#include "../legacyheaders/typedefs.h"
-#include "futil.h"
+
+#include "gromacs/math/vectypes.h"
+#include "gromacs/utility/cstringutil.h"
+#include "gromacs/utility/futil.h"
+#include "gromacs/utility/real.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -63,9 +66,6 @@ enum {
 
 typedef struct t_fileio t_fileio;
 
-extern const char *itemstr[eitemNR];
-extern const char *comment_str[eitemNR];
-
 /* NOTE ABOUT THREAD SAFETY:
 
    The functions are all thread-safe, provided that two threads don't
@@ -80,11 +80,6 @@ extern const char *comment_str[eitemNR];
 t_fileio *gmx_fio_open(const char *fn, const char *mode);
 /* Open a new file for reading or writing.
  * The file type will be deduced from the file name.
- * If fn is NULL, stdin / stdout will be used for Ascii I/O (TPA type)
- * mode may be "r", "w", or "a". You should append a "b" to the mode
- * if you are writing a binary file, but the routine will also
- * doublecheck it and try to do it if you forgot. This has no effect on
- * unix, but is important on windows.
  */
 
 int gmx_fio_close(t_fileio *fp);
@@ -147,7 +142,7 @@ void gmx_fio_checktype(t_fileio *fio);
  ***************************************************/
 
 void gmx_fio_rewind(t_fileio *fio);
-/* Rewind the tpa file in fio */
+/* Rewind the file in fio */
 
 int gmx_fio_flush(t_fileio *fio);
 /* Flush the fio, returns 0 on success */
