@@ -3,7 +3,7 @@
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
  * Copyright (c) 2001-2007, The GROMACS development team.
- * Copyright (c) 2013,2014, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2015, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -34,36 +34,28 @@
  * To help us fund GROMACS development, we humbly ask that you cite
  * the research papers on the package. Check out http://www.gromacs.org.
  */
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "gmxpre.h"
 
 #include <math.h>
 
-#include "sysstuff.h"
-#include "typedefs.h"
-#include "macros.h"
-#include "vec.h"
-#include "pbc.h"
-#include "rmpbc.h"
 #include "gromacs/commandline/pargs.h"
-#include "xvgr.h"
-#include "gromacs/fileio/futil.h"
+#include "gromacs/fileio/matio.h"
 #include "gromacs/fileio/tpxio.h"
 #include "gromacs/fileio/trxio.h"
-#include "index.h"
+#include "gromacs/fileio/xvgr.h"
+#include "gromacs/gmxana/gmx_ana.h"
+#include "gromacs/gmxana/gstat.h"
+#include "gromacs/legacyheaders/macros.h"
+#include "gromacs/legacyheaders/nrnb.h"
+#include "gromacs/legacyheaders/typedefs.h"
+#include "gromacs/math/units.h"
+#include "gromacs/math/vec.h"
+#include "gromacs/pbcutil/pbc.h"
+#include "gromacs/topology/index.h"
+#include "gromacs/topology/mtop_util.h"
+#include "gromacs/utility/fatalerror.h"
+#include "gromacs/utility/futil.h"
 #include "gromacs/utility/smalloc.h"
-#include "calcgrid.h"
-#include "nrnb.h"
-#include "physics.h"
-#include "coulomb.h"
-#include "pme.h"
-#include "gstat.h"
-#include "gromacs/fileio/matio.h"
-#include "mtop_util.h"
-#include "gmx_ana.h"
-
-#include "gromacs/legacyheaders/gmx_fatal.h"
 
 static void clust_size(const char *ndx, const char *trx, const char *xpm,
                        const char *xpmw, const char *ncl, const char *acl,
@@ -152,7 +144,7 @@ static void clust_size(const char *ndx, const char *trx, const char *xpm,
         {
             index[i] = i;
         }
-        gname = strdup("mols");
+        gname = gmx_strdup("mols");
     }
     else
     {
@@ -309,7 +301,7 @@ static void clust_size(const char *ndx, const char *trx, const char *xpm,
             {
                 if (bTPRwarn)
                 {
-                    printf("You need a [TT].tpr[tt] file to analyse temperatures\n");
+                    printf("You need a [REF].tpr[ref] file to analyse temperatures\n");
                     bTPRwarn = FALSE;
                 }
             }
@@ -338,10 +330,10 @@ static void clust_size(const char *ndx, const char *trx, const char *xpm,
     }
     while (read_next_frame(oenv, status, &fr));
     close_trx(status);
-    gmx_ffclose(fp);
-    gmx_ffclose(gp);
-    gmx_ffclose(hp);
-    gmx_ffclose(tp);
+    xvgrclose(fp);
+    xvgrclose(gp);
+    xvgrclose(hp);
+    xvgrclose(tp);
 
     gmx_mtop_atomlookup_destroy(alook);
 
@@ -384,7 +376,7 @@ static void clust_size(const char *ndx, const char *trx, const char *xpm,
         nhisto += (int)((j+1)*nelem/n_x);
     }
     fprintf(fp, "%5d  %8.3f\n", j+1, 0.0);
-    gmx_ffclose(fp);
+    xvgrclose(fp);
 
     fprintf(stderr, "Total number of atoms in clusters =  %d\n", nhisto);
 
@@ -441,14 +433,14 @@ int gmx_clustsize(int argc, char *argv[])
 {
     const char     *desc[] = {
         "[THISMODULE] computes the size distributions of molecular/atomic clusters in",
-        "the gas phase. The output is given in the form of an [TT].xpm[tt] file.",
-        "The total number of clusters is written to an [TT].xvg[tt] file.[PAR]",
+        "the gas phase. The output is given in the form of an [REF].xpm[ref] file.",
+        "The total number of clusters is written to an [REF].xvg[ref] file.[PAR]",
         "When the [TT]-mol[tt] option is given clusters will be made out of",
         "molecules rather than atoms, which allows clustering of large molecules.",
         "In this case an index file would still contain atom numbers",
         "or your calculation will die with a SEGV.[PAR]",
         "When velocities are present in your trajectory, the temperature of",
-        "the largest cluster will be printed in a separate [TT].xvg[tt] file assuming",
+        "the largest cluster will be printed in a separate [REF].xvg[ref] file assuming",
         "that the particles are free to move. If you are using constraints,",
         "please correct the temperature. For instance water simulated with SHAKE",
         "or SETTLE will yield a temperature that is 1.5 times too low. You can",
@@ -473,13 +465,13 @@ int gmx_clustsize(int argc, char *argv[])
         { "-cut",      FALSE, etREAL, {&cutoff},
           "Largest distance (nm) to be considered in a cluster" },
         { "-mol",      FALSE, etBOOL, {&bMol},
-          "Cluster molecules rather than atoms (needs [TT].tpr[tt] file)" },
+          "Cluster molecules rather than atoms (needs [REF].tpr[ref] file)" },
         { "-pbc",      FALSE, etBOOL, {&bPBC},
           "Use periodic boundary conditions" },
         { "-nskip",    FALSE, etINT,  {&nskip},
           "Number of frames to skip between writing" },
         { "-nlevels",  FALSE, etINT,  {&nlevels},
-          "Number of levels of grey in [TT].xpm[tt] output" },
+          "Number of levels of grey in [REF].xpm[ref] output" },
         { "-ndf",      FALSE, etINT,  {&ndf},
           "Number of degrees of freedom of the entire system for temperature calculation. If not set, the number of atoms times three is used." },
         { "-rgblo",    FALSE, etRVEC, {rlo},
@@ -508,7 +500,7 @@ int gmx_clustsize(int argc, char *argv[])
 #define NFILE asize(fnm)
 
     if (!parse_common_args(&argc, argv,
-                           PCA_CAN_VIEW | PCA_CAN_TIME | PCA_TIME_UNIT | PCA_BE_NICE,
+                           PCA_CAN_VIEW | PCA_CAN_TIME | PCA_TIME_UNIT,
                            NFILE, fnm, NPA, pa, asize(desc), desc, 0, NULL, &oenv))
     {
         return 0;
