@@ -3,7 +3,7 @@
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
  * Copyright (c) 2001-2004, The GROMACS development team.
- * Copyright (c) 2013,2014, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2015, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -34,36 +34,32 @@
  * To help us fund GROMACS development, we humbly ask that you cite
  * the research papers on the package. Check out http://www.gromacs.org.
  */
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "gmxpre.h"
 
 #include <math.h>
 #include <string.h>
 
-#include "gromacs/fileio/pdbio.h"
-#include "gromacs/fileio/confio.h"
-#include "symtab.h"
-#include "gromacs/utility/smalloc.h"
-#include "macros.h"
 #include "gromacs/commandline/pargs.h"
+#include "gromacs/fileio/confio.h"
+#include "gromacs/fileio/pdbio.h"
 #include "gromacs/fileio/strdb.h"
-#include "index.h"
-#include "vec.h"
-#include "typedefs.h"
-#include "gromacs/gmxlib/conformation-utilities.h"
-#include "physics.h"
-#include "atomprop.h"
 #include "gromacs/fileio/tpxio.h"
 #include "gromacs/fileio/trxio.h"
-#include "pbc.h"
-#include "princ.h"
-#include "txtdump.h"
-#include "viewit.h"
-#include "rmpbc.h"
-#include "gmx_ana.h"
-
-#include "gromacs/legacyheaders/gmx_fatal.h"
+#include "gromacs/gmxana/gmx_ana.h"
+#include "gromacs/gmxana/princ.h"
+#include "gromacs/gmxlib/conformation-utilities.h"
+#include "gromacs/legacyheaders/macros.h"
+#include "gromacs/legacyheaders/txtdump.h"
+#include "gromacs/legacyheaders/typedefs.h"
+#include "gromacs/legacyheaders/viewit.h"
+#include "gromacs/math/units.h"
+#include "gromacs/math/vec.h"
+#include "gromacs/pbcutil/pbc.h"
+#include "gromacs/pbcutil/rmpbc.h"
+#include "gromacs/topology/atomprop.h"
+#include "gromacs/topology/index.h"
+#include "gromacs/utility/fatalerror.h"
+#include "gromacs/utility/smalloc.h"
 
 typedef struct
 {
@@ -344,7 +340,7 @@ void pdb_legend(FILE *out, int natoms, int nres, t_atoms *atoms, rvec x[])
     for (i = 1; (i < 12); i++)
     {
         fprintf(out,
-                "%-6s%5u  %-4.4s%3.3s %c%4d%c   %8.3f%8.3f%8.3f%6.2f%6.2f\n",
+                "%-6s%5d  %-4.4s%3.3s %c%4d%c   %8.3f%8.3f%8.3f%6.2f%6.2f\n",
                 "ATOM  ", natoms + 1 + i, "CA", "LEG", space, nres + 1, space,
                 (xmin + (i * 0.12)) * 10, ymin * 10, zmin * 10, 1.0, bfac_min
                 + ((i - 1.0) * (bfac_max - bfac_min) / 10));
@@ -523,8 +519,8 @@ int gmx_editconf(int argc, char *argv[])
 {
     const char     *desc[] =
     {
-        "[THISMODULE] converts generic structure format to [TT].gro[tt], [TT].g96[tt]",
-        "or [TT].pdb[tt].",
+        "[THISMODULE] converts generic structure format to [REF].gro[ref], [TT].g96[tt]",
+        "or [REF].pdb[ref].",
         "[PAR]",
         "The box can be modified with options [TT]-box[tt], [TT]-d[tt] and",
         "[TT]-angles[tt]. Both [TT]-box[tt] and [TT]-d[tt]",
@@ -566,7 +562,7 @@ int gmx_editconf(int argc, char *argv[])
         "[PAR]",
         "Scaling is applied before any of the other operations are",
         "performed. Boxes and coordinates can be scaled to give a certain density (option",
-        "[TT]-density[tt]). Note that this may be inaccurate in case a [TT].gro[tt]",
+        "[TT]-density[tt]). Note that this may be inaccurate in case a [REF].gro[ref]",
         "file is given as input. A special feature of the scaling option is that when the",
         "factor -1 is given in one dimension, one obtains a mirror image,",
         "mirrored in one of the planes. When one uses -1 in three dimensions, ",
@@ -576,7 +572,7 @@ int gmx_editconf(int argc, char *argv[])
         "It is important that the box vectors at the bottom of your input file",
         "are correct when the periodicity is to be removed.",
         "[PAR]",
-        "When writing [TT].pdb[tt] files, B-factors can be",
+        "When writing [REF].pdb[ref] files, B-factors can be",
         "added with the [TT]-bf[tt] option. B-factors are read",
         "from a file with with following format: first line states number of",
         "entries in the file, next lines state an index",
@@ -587,7 +583,7 @@ int gmx_editconf(int argc, char *argv[])
         "a row of CA atoms with B-factors ranging from the minimum to the",
         "maximum value found, effectively making a legend for viewing.",
         "[PAR]",
-        "With the option [TT]-mead[tt] a special [TT].pdb[tt] ([TT].pqr[tt])",
+        "With the option [TT]-mead[tt] a special [REF].pdb[ref] ([REF].pqr[ref])",
         "file for the MEAD electrostatics",
         "program (Poisson-Boltzmann solver) can be made. A further prerequisite",
         "is that the input file is a run input file.",
@@ -602,11 +598,13 @@ int gmx_editconf(int argc, char *argv[])
         "with an optional center of rotation specified by [TT]-aligncenter[tt].",
         "[PAR]",
         "Finally, with option [TT]-label[tt], [TT]editconf[tt] can add a chain identifier",
-        "to a [TT].pdb[tt] file, which can be useful for analysis with e.g. Rasmol.",
+        "to a [REF].pdb[ref] file, which can be useful for analysis with e.g. Rasmol.",
         "[PAR]",
         "To convert a truncated octrahedron file produced by a package which uses",
-        "a cubic box with the corners cut off (such as GROMOS), use:[BR]",
-        "[TT]gmx editconf -f in -rotate 0 45 35.264 -bt o -box veclen -o out[tt][BR]",
+        "a cubic box with the corners cut off (such as GROMOS), use::",
+        "",
+        "  gmx editconf -f in -rotate 0 45 35.264 -bt o -box veclen -o out",
+        "",
         "where [TT]veclen[tt] is the size of the cubic box times [SQRT]3[sqrt]/2."
     };
     const char     *bugs[] =
@@ -706,7 +704,7 @@ int gmx_editconf(int argc, char *argv[])
         {
             "-conect", FALSE, etBOOL,
             { &bCONECT },
-            "Add CONECT records to a [TT].pdb[tt] file when written. Can only be done when a topology is present"
+            "Add CONECT records to a [REF].pdb[ref] file when written. Can only be done when a topology is present"
         }
     };
 #define NPA asize(pa)
@@ -796,11 +794,9 @@ int gmx_editconf(int argc, char *argv[])
         gmx_fatal(FARGS, "Output file should be a .pdb file"
                   " when using the -grasp option\n");
     }
-    if ((bMead || bGrasp) && !((fn2ftp(infile) == efTPR) ||
-                               (fn2ftp(infile) == efTPA) ||
-                               (fn2ftp(infile) == efTPB)))
+    if ((bMead || bGrasp) && (fn2ftp(infile) != efTPR))
     {
-        gmx_fatal(FARGS, "Input file should be a .tp[abr] file"
+        gmx_fatal(FARGS, "Input file should be a .tpr file"
                   " when using the -mead option\n");
     }
 
