@@ -3,7 +3,7 @@
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
  * Copyright (c) 2001-2004, The GROMACS development team.
- * Copyright (c) 2013,2014, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2015, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -34,23 +34,23 @@
  * To help us fund GROMACS development, we humbly ask that you cite
  * the research papers on the package. Check out http://www.gromacs.org.
  */
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "gmxpre.h"
+
+#include <math.h>
+#include <stdlib.h>
 #include <string.h>
-#include <math.h>
 
-#include "typedefs.h"
-#include "gromacs/utility/smalloc.h"
 #include "gromacs/commandline/pargs.h"
-#include "disre.h"
-#include "names.h"
-#include "macros.h"
-#include "gmx_fatal.h"
 #include "gromacs/fileio/enxio.h"
-#include "vec.h"
-#include "gmx_ana.h"
 #include "gromacs/fileio/trxio.h"
+#include "gromacs/gmxana/gmx_ana.h"
+#include "gromacs/legacyheaders/disre.h"
+#include "gromacs/legacyheaders/macros.h"
+#include "gromacs/legacyheaders/names.h"
+#include "gromacs/legacyheaders/typedefs.h"
+#include "gromacs/math/vec.h"
+#include "gromacs/utility/fatalerror.h"
+#include "gromacs/utility/smalloc.h"
 
 #define TIME_EXPLICIT 0
 #define TIME_CONTINUE 1
@@ -492,7 +492,7 @@ static void update_ee_sum(int nre,
 int gmx_eneconv(int argc, char *argv[])
 {
     const char     *desc[] = {
-        "With [IT]multiple files[it] specified for the [TT]-f[tt] option:[BR]",
+        "With [IT]multiple files[it] specified for the [TT]-f[tt] option:[PAR]",
         "Concatenates several energy files in sorted order.",
         "In the case of double time frames, the one",
         "in the later file is used. By specifying [TT]-settime[tt] you will be",
@@ -500,7 +500,7 @@ int gmx_eneconv(int argc, char *argv[])
         "from the command line,",
         "such that the command [TT]gmx eneconv -f *.edr -o fixed.edr[tt] should do",
         "the trick. [PAR]",
-        "With [IT]one file[it] specified for [TT]-f[tt]:[BR]",
+        "With [IT]one file[it] specified for [TT]-f[tt]:[PAR]",
         "Reads one energy file and writes another, applying the [TT]-dt[tt],",
         "[TT]-offset[tt], [TT]-t0[tt] and [TT]-settime[tt] options and",
         "converting to a different format if necessary (indicated by file",
@@ -571,7 +571,7 @@ int gmx_eneconv(int argc, char *argv[])
           "Stop on errors in the file" }
     };
 
-    if (!parse_common_args(&argc, argv, PCA_BE_NICE, NFILE, fnm, asize(pa),
+    if (!parse_common_args(&argc, argv, 0, NFILE, fnm, asize(pa),
                            pa, asize(desc), desc, asize(bugs), bugs, &oenv))
     {
         return 0;
@@ -581,7 +581,6 @@ int gmx_eneconv(int argc, char *argv[])
     nset     = 0;
     timestep = 0.0;
     snew(fnms, argc);
-    nfile        = 0;
     lastfilestep = 0;
     laststep     = startstep = 0;
 
