@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2012,2013,2014, by the GROMACS development team, led by
+ * Copyright (c) 2012,2013,2014,2015, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -36,35 +36,29 @@
  * on the code from g_anaeig. You can reach him as olange@gwdg.de. He
  * probably also holds copyright to the following code.
  */
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "gmxpre.h"
 
+#include <ctype.h>
 #include <math.h>
 #include <stdlib.h>
-#include <ctype.h>
 #include <string.h>
-#include "readinp.h"
+
 #include "gromacs/commandline/pargs.h"
-#include "sysstuff.h"
-#include "typedefs.h"
-#include "gromacs/utility/smalloc.h"
-#include "macros.h"
-#include "gmx_fatal.h"
-#include "vec.h"
-#include "pbc.h"
-#include "gromacs/fileio/futil.h"
-#include "gromacs/fileio/pdbio.h"
 #include "gromacs/fileio/confio.h"
+#include "gromacs/fileio/pdbio.h"
 #include "gromacs/fileio/tpxio.h"
-#include "gromacs/fileio/matio.h"
-#include "mshift.h"
-#include "xvgr.h"
-#include "rmpbc.h"
-#include "txtdump.h"
-#include "eigio.h"
-#include "index.h"
+#include "gromacs/fileio/xvgr.h"
+#include "gromacs/gmxana/eigio.h"
+#include "gromacs/legacyheaders/macros.h"
+#include "gromacs/legacyheaders/readinp.h"
+#include "gromacs/legacyheaders/txtdump.h"
+#include "gromacs/legacyheaders/typedefs.h"
+#include "gromacs/math/vec.h"
+#include "gromacs/topology/index.h"
 #include "gromacs/utility/cstringutil.h"
+#include "gromacs/utility/fatalerror.h"
+#include "gromacs/utility/futil.h"
+#include "gromacs/utility/smalloc.h"
 
 typedef struct
 {
@@ -585,14 +579,14 @@ int gmx_make_edi(int argc, char *argv[])
         "to keep the position along a certain (set of) coordinate(s) fixed ([TT]-linfix[tt]),",
         "or to only monitor the projections of the positions onto",
         "these coordinates ([TT]-mon[tt]).[PAR]",
-        "References:[BR]",
+        "References:[PAR]",
         "A. Amadei, A.B.M. Linssen, B.L. de Groot, D.M.F. van Aalten and ",
         "H.J.C. Berendsen; An efficient method for sampling the essential subspace ",
-        "of proteins., J. Biomol. Struct. Dyn. 13:615-626 (1996)[BR]",
+        "of proteins., J. Biomol. Struct. Dyn. 13:615-626 (1996)[PAR]",
         "B.L. de Groot, A. Amadei, D.M.F. van Aalten and H.J.C. Berendsen; ",
         "Towards an exhaustive sampling of the configurational spaces of the ",
         "two forms of the peptide hormone guanylin,",
-        "J. Biomol. Struct. Dyn. 13 : 741-751 (1996)[BR]",
+        "J. Biomol. Struct. Dyn. 13 : 741-751 (1996)[PAR]",
         "B.L. de Groot, A.Amadei, R.M. Scheek, N.A.J. van Nuland and H.J.C. Berendsen; ",
         "An extended sampling of the configurational space of HPr from E. coli",
         "Proteins: Struct. Funct. Gen. 26: 314-322 (1996)",
@@ -612,7 +606,7 @@ int gmx_make_edi(int argc, char *argv[])
         "[TT]-radcon[tt]: perform acceptance radius contraction along selected eigenvectors",
         "towards a target structure specified with [TT]-tar[tt].[PAR]",
         "NOTE: each eigenvector can be selected only once. [PAR]",
-        "[TT]-outfrq[tt]: frequency (in steps) of writing out projections etc. to [TT].xvg[tt] file[PAR]",
+        "[TT]-outfrq[tt]: frequency (in steps) of writing out projections etc. to [REF].xvg[ref] file[PAR]",
         "[TT]-slope[tt]: minimal slope in acceptance radius expansion. A new expansion",
         "cycle will be started if the spontaneous increase of the radius (in nm/step)",
         "is less than the value specified.[PAR]",
@@ -625,19 +619,20 @@ int gmx_make_edi(int argc, char *argv[])
         "lower as in a free MD simulation, especially on a large number of ranks and/or",
         "when the ED group contains a lot of atoms. [PAR]",
         "Please also note that if your ED group contains more than a single protein,",
-        "then the [TT].tpr[tt] file must contain the correct PBC representation of the ED group.",
+        "then the [REF].tpr[ref] file must contain the correct PBC representation of the ED group.",
         "Take a look on the initial RMSD from the reference structure, which is printed",
         "out at the start of the simulation; if this is much higher than expected, one",
         "of the ED molecules might be shifted by a box vector. [PAR]",
-        "All ED-related output of [TT]mdrun[tt] (specify with [TT]-eo[tt]) is written to a [TT].xvg[tt] file",
+        "All ED-related output of [TT]mdrun[tt] (specify with [TT]-eo[tt]) is written to a [REF].xvg[ref] file",
         "as a function of time in intervals of OUTFRQ steps.[PAR]",
         "[BB]Note[bb] that you can impose multiple ED constraints and flooding potentials in",
-        "a single simulation (on different molecules) if several [TT].edi[tt] files were concatenated",
-        "first. The constraints are applied in the order they appear in the [TT].edi[tt] file. ",
-        "Depending on what was specified in the [TT].edi[tt] input file, the output file contains for each ED dataset[PAR]",
-        "[TT]*[tt] the RMSD of the fitted molecule to the reference structure (for atoms involved in fitting prior to calculating the ED constraints)[BR]",
-        "[TT]*[tt] projections of the positions onto selected eigenvectors[BR]",
-        "[PAR][PAR]",
+        "a single simulation (on different molecules) if several [REF].edi[ref] files were concatenated",
+        "first. The constraints are applied in the order they appear in the [REF].edi[ref] file. ",
+        "Depending on what was specified in the [REF].edi[ref] input file, the output file contains for each ED dataset",
+        "",
+        " * the RMSD of the fitted molecule to the reference structure (for atoms involved in fitting prior to calculating the ED constraints)",
+        " * projections of the positions onto selected eigenvectors",
+        "",
         "FLOODING:[PAR]",
         "with [TT]-flood[tt], you can specify which eigenvectors are used to compute a flooding potential,",
         "which will lead to extra forces expelling the structure out of the region described",
@@ -660,7 +655,7 @@ int gmx_make_edi(int argc, char *argv[])
         "[PAR]",
         "RESTART and FLOODING:",
         "If you want to restart a crashed flooding simulation please find the values deltaF and Efl in",
-        "the output file and manually put them into the [TT].edi[tt] file under DELTA_F0 and EFL_NULL."
+        "the output file and manually put them into the [REF].edi[ref] file under DELTA_F0 and EFL_NULL."
     };
 
     /* Save all the params in this struct and then save it in an edi file.
@@ -706,7 +701,7 @@ int gmx_make_edi(int argc, char *argv[])
         { "-flood",  FALSE, etSTR, {&evSelections[2]},
           "Indices of eigenvectors for flooding"},
         { "-outfrq", FALSE, etINT, {&edi_params.outfrq},
-          "Freqency (in steps) of writing output in [TT].xvg[tt] file" },
+          "Freqency (in steps) of writing output in [REF].xvg[ref] file" },
         { "-slope", FALSE, etREAL, { &edi_params.slope},
           "Minimal slope in acceptance radius expansion"},
         { "-linstep", FALSE, etSTR, {&evParams[0]},
@@ -862,7 +857,6 @@ int gmx_make_edi(int argc, char *argv[])
         printf("\n");
     }
 
-    EigvecFile = NULL;
     EigvecFile = opt2fn("-f", NFILE, fnm);
 
     /*read eigenvectors from eigvec.trr*/
