@@ -91,7 +91,7 @@ Arch       = 'avx_128_fma_single'
 # 'cutoff' means the interaction is set to 0.0 outside the cutoff
 #
 
-FileHeader = create_copyright_header('2012,2013')
+FileHeader = create_copyright_header('2012,2013,2014')
 FileHeader += """/*
  * Note: this file was generated by the GROMACS """+Arch+""" kernel generator.
  */
@@ -428,8 +428,7 @@ numKernels = 0
 
 fpdecl = open('nb_kernel_' + Arch + '.c','w')
 fpdecl.write( FileHeader )
-fpdecl.write( '#ifndef nb_kernel_' + Arch + '_h\n' )
-fpdecl.write( '#define nb_kernel_' + Arch + '_h\n\n' )
+fpdecl.write( '#include "gmxpre.h"\n\n' )
 fpdecl.write( '#include "../nb_kernel.h"\n\n' )
 
 for KernelElec in ElectrostaticsList:
@@ -512,6 +511,5 @@ for decl in kerneldecl[0:-1]:
 fpdecl.write( kerneldecl[-1] + '\n' )
 fpdecl.write( '};\n\n' )
 fpdecl.write( 'int\n' )
-fpdecl.write( '    kernellist_'+Arch+'_size = sizeof(kernellist_'+Arch+')/sizeof(kernellist_'+Arch+'[0]);\n\n')
-fpdecl.write( '#endif\n')
+fpdecl.write( '    kernellist_'+Arch+'_size = sizeof(kernellist_'+Arch+')/sizeof(kernellist_'+Arch+'[0]);\n')
 fpdecl.close()
