@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2012,2013,2014, by the GROMACS development team, led by
+ * Copyright (c) 2012,2013,2014,2015, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -39,9 +39,26 @@
 #include "gromacs/simd/simd.h"
 #include "gromacs/simd/simd_math.h"
 
-/* Fujitsu header borrows the name from SSE2, since some instructions have aliases */
+/* Fujitsu header borrows the name from SSE2, since some instructions have aliases.
+ * Environment/compiler version GM-1.2.0-17 seems to be buggy; when -Xg is
+ * defined to enable GNUC extensions, this sets _ISOC99_SOURCE, which in
+ * turn causes all intrinsics to be declared inline _instead_ of static. This
+ * leads to duplicate symbol errors at link time.
+ * To work around this we unset this before including the HPC-ACE header, and
+ * reset the value afterwards.
+ */
+#ifdef _ISOC99_SOURCE
+#    undef _ISOC99_SOURCE
+#    define SAVE_ISOC99_SOURCE
+#endif
+
 #include <emmintrin.h>
 
+#ifdef SAVE_ISOC99_SOURCE
+#    define _ISOC99_SOURCE
+#    undef SAVE_ISOC99_SOURCE
+#endif
+
 #define GMX_FJSP_SHUFFLE2(x, y) (((x)<<1) | (y))
 
 #define GMX_FJSP_TRANSPOSE2_V2R8(row0, row1) {           \
