@@ -35,14 +35,12 @@
  * the research papers on the package. Check out http://www.gromacs.org.
  */
 /* This file is completely threadsafe - keep it that way! */
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "gmxpre.h"
 
-#include "typedefs.h"
-#include "main.h"
-#include "network.h"
-#include "rbin.h"
+#include "gromacs/legacyheaders/rbin.h"
+
+#include "gromacs/legacyheaders/network.h"
+#include "gromacs/legacyheaders/typedefs.h"
 #include "gromacs/utility/smalloc.h"
 
 t_bin *mk_bin(void)
@@ -88,7 +86,7 @@ int add_binr(t_bin *b, int nr, real r[])
     /* Copy pointer */
     rbuf = b->rbuf+b->nreal;
 
-#if (__ICC >= 1500 || __ICL >= 1500) && defined __MIC__
+#if (defined __ICC && __ICC >= 1500 || defined __ICL && __ICL >= 1500) && defined __MIC__
 #pragma novector /* Work-around for incorrect vectorization */
 #endif
     for (i = 0; (i < nr); i++)
