@@ -3,7 +3,7 @@
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
  * Copyright (c) 2001-2004, The GROMACS development team.
- * Copyright (c) 2013,2014, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2015, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -38,9 +38,9 @@
 #ifndef GMX_GMXPREPROCESS_READIR_H
 #define GMX_GMXPREPROCESS_READIR_H
 
-#include "typedefs.h"
-#include "readinp.h"
-#include "grompp-impl.h"
+#include "gromacs/gmxpreprocess/grompp-impl.h"
+#include "gromacs/legacyheaders/readinp.h"
+#include "gromacs/legacyheaders/typedefs.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -66,7 +66,6 @@ typedef struct {
     gmx_bool bOrire;
     gmx_bool bMorse;
     char    *wall_atomtype[2];
-    gmx_bool pull_start;
     char    *couple_moltype;
     int      couple_lam0;
     int      couple_lam1;
@@ -90,7 +89,9 @@ void check_ir(const char *mdparin, t_inputrec *ir, t_gromppopts *opts,
 int search_string(const char *s, int ng, char *gn[]);
 /* Returns the index of string s in the index groups */
 
-void double_check(t_inputrec *ir, matrix box, gmx_bool bConstr,
+void double_check(t_inputrec *ir, matrix box,
+                  gmx_bool bHasNormalConstraints,
+                  gmx_bool bHasAnyConstraints,
                   warninp_t wi);
 /* Do more checks */
 
@@ -126,22 +127,22 @@ void do_index(const char* mdparin,
 /* Routines In readpull.c */
 
 char **read_pullparams(int *ninp_p, t_inpfile **inp,
-                       t_pull *pull, gmx_bool *bStart,
+                       pull_params_t *pull,
                        warninp_t wi);
 /* Reads the pull parameters, returns a list of the pull group names */
 
-void make_pull_groups(t_pull *pull,
+void make_pull_groups(pull_params_t *pull,
                       char **pgnames,
                       const t_blocka *grps, char **gnames);
 /* Process the pull group parameters after reading the index groups */
 
-void make_pull_coords(t_pull *pull);
+void make_pull_coords(pull_params_t *pull);
 /* Process the pull coordinates after reading the pull groups */
 
 void set_pull_init(t_inputrec *ir, gmx_mtop_t *mtop, rvec *x, matrix box, real lambda,
-                   const output_env_t oenv, gmx_bool bStart);
+                   const output_env_t oenv);
 /* Prints the initial pull group distances in x.
- * If bStart adds the distance to the initial reference location.
+ * If requested, adds the current distance to the initial reference location.
  */
 
 int str_nelem(const char *str, int maxptr, char *ptr[]);
