@@ -38,10 +38,10 @@
 #ifndef GMX_GMXPREPROCESS_RESALL_H
 #define GMX_GMXPREPROCESS_RESALL_H
 
-#include "typedefs.h"
-#include "hackblock.h"
-#include "gpp_atomtype.h"
-#include "grompp-impl.h"
+#include "gromacs/gmxpreprocess/gpp_atomtype.h"
+#include "gromacs/gmxpreprocess/grompp-impl.h"
+#include "gromacs/gmxpreprocess/hackblock.h"
+#include "gromacs/legacyheaders/typedefs.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -58,11 +58,11 @@ t_restp *get_restp(const char *rtpname, int nrtp, t_restp rtp[]);
  * Generates a fatal error when rtpname is not found.
  */
 
-gpp_atomtype_t read_atype(const char *ffdir, t_symtab *tab);
+gpp_atomtype_t read_atype(const char *ffdir, struct t_symtab *tab);
 /* read atom type database(s) */
 
 void read_resall(char *resdb, int *nrtp, t_restp **rtp,
-                 gpp_atomtype_t atype, t_symtab *tab,
+                 gpp_atomtype_t atype, struct t_symtab *tab,
                  gmx_bool bAllowOverrideRTP);
 /* read rtp database, append to the existing database */
 
