@@ -3,7 +3,7 @@
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
  * Copyright (c) 2001-2004, The GROMACS development team.
- * Copyright (c) 2012,2014, by the GROMACS development team, led by
+ * Copyright (c) 2012,2014,2015, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -38,10 +38,10 @@
 #ifndef GMX_GMXPREPROCESS_TOPIO_H
 #define GMX_GMXPREPROCESS_TOPIO_H
 
-#include "typedefs.h"
-#include "readir.h"
-#include "grompp-impl.h"
-#include "gpp_atomtype.h"
+#include "gromacs/gmxpreprocess/gpp_atomtype.h"
+#include "gromacs/gmxpreprocess/grompp-impl.h"
+#include "gromacs/gmxpreprocess/readir.h"
+#include "gromacs/legacyheaders/typedefs.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -55,7 +55,7 @@ char **do_top(gmx_bool         bVerbose,
               const char      *topppfile,
               t_gromppopts    *opts,
               gmx_bool         bZero,
-              t_symtab        *symtab,
+              struct t_symtab *symtab,
               t_params         plist[],
               int             *combination_rule,
               double          *repulsion_power,
@@ -63,13 +63,13 @@ char **do_top(gmx_bool         bVerbose,
               gpp_atomtype_t   atype,
               int             *nrmols,
               t_molinfo      **molinfo,
+              t_molinfo      **intermolecular_interactions,
               t_inputrec      *ir,
               int             *nmolblock,
               gmx_molblock_t **molblock,
               gmx_bool         bGB,
               warninp_t        wi);
 
-
 /* This routine expects sys->molt[m].ilist to be of size F_NRE and ordered. */
 void generate_qmexcl(gmx_mtop_t *sys, t_inputrec *ir, warninp_t    wi);
 
