@@ -38,11 +38,11 @@
 #ifndef GMX_GMXPREPROCESS_TOPPUSH_H
 #define GMX_GMXPREPROCESS_TOPPUSH_H
 
-#include "typedefs.h"
-#include "toputil.h"
-#include "gpp_atomtype.h"
-#include "gpp_bond_atomtype.h"
-#include "warninp.h"
+#include "gromacs/gmxpreprocess/gpp_atomtype.h"
+#include "gromacs/gmxpreprocess/gpp_bond_atomtype.h"
+#include "gromacs/gmxpreprocess/toputil.h"
+#include "gromacs/legacyheaders/typedefs.h"
+#include "gromacs/legacyheaders/warninp.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -60,7 +60,7 @@ void generate_nbparams(int comb, int funct, t_params plist[],
                        gpp_atomtype_t atype,
                        warninp_t wi);
 
-void push_at (t_symtab *symtab, gpp_atomtype_t at,
+void push_at (struct t_symtab *symtab, gpp_atomtype_t at,
               t_bond_atomtype bat, char *line, int nb_funct,
               t_nbparam ***nbparam, t_nbparam ***pair,
               warninp_t wi);
@@ -86,13 +86,13 @@ push_gb_params(gpp_atomtype_t atype,
                char          *line,
                warninp_t      wi);
 
-void push_atom(t_symtab      *symtab,
-               t_block       *cgs,
-               t_atoms       *at,
-               gpp_atomtype_t atype,
-               char          *line,
-               int           *lastcg,
-               warninp_t      wi);
+void push_atom(struct t_symtab *symtab,
+               t_block         *cgs,
+               t_atoms         *at,
+               gpp_atomtype_t   atype,
+               char            *line,
+               int             *lastcg,
+               warninp_t        wi);
 
 void push_bond(directive d, t_params bondtype[], t_params bond[],
                t_atoms *at, gpp_atomtype_t atype, char *line,
@@ -112,7 +112,7 @@ void push_mol(int nrmols, t_molinfo mols[], char *pline,
               int *whichmol, int *nrcopies,
               warninp_t wi);
 
-void push_molt(t_symtab *symtab, int *nmol, t_molinfo **mol, char *line,
+void push_molt(struct t_symtab *symtab, int *nmol, t_molinfo **mol, char *line,
                warninp_t wi);
 
 void init_block2(t_block2 *b2, int natom);
@@ -127,7 +127,7 @@ void b_to_b2(t_blocka *b, t_block2 *b2);
 
 void b2_to_b(t_block2 *b2, t_blocka *b);
 
-int add_atomtype_decoupled(t_symtab *symtab, gpp_atomtype_t at,
+int add_atomtype_decoupled(struct t_symtab *symtab, gpp_atomtype_t at,
                            t_nbparam ***nbparam, t_nbparam ***pair);
 /* Add an atom type with all parameters set to zero (no interactions).
  * Returns the atom type number.
