@@ -3,7 +3,7 @@
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
  * Copyright (c) 2001-2004, The GROMACS development team.
- * Copyright (c) 2013,2014, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2015, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -34,27 +34,25 @@
  * To help us fund GROMACS development, we humbly ask that you cite
  * the research papers on the package. Check out http://www.gromacs.org.
  */
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "gmxpre.h"
 
-#include <stdio.h>
-#include <math.h>
-#include <assert.h>
-#include <string.h>
 #include "vsite_parm.h"
-#include "gromacs/utility/smalloc.h"
-#include "resall.h"
-#include "add_par.h"
-#include "vec.h"
-#include "toputil.h"
-#include "physics.h"
-#include "index.h"
-#include "names.h"
-#include "gmx_fatal.h"
+
+#include <assert.h>
+#include <math.h>
+#include <stdio.h>
+#include <string.h>
+
+#include "gromacs/gmxpreprocess/add_par.h"
+#include "gromacs/gmxpreprocess/resall.h"
+#include "gromacs/gmxpreprocess/toputil.h"
+#include "gromacs/legacyheaders/macros.h"
+#include "gromacs/legacyheaders/names.h"
+#include "gromacs/math/units.h"
+#include "gromacs/math/vec.h"
 #include "gromacs/utility/cstringutil.h"
-#include "physics.h"
-#include "macros.h"
+#include "gromacs/utility/fatalerror.h"
+#include "gromacs/utility/smalloc.h"
 
 typedef struct {
     t_iatom a[4];
@@ -291,7 +289,7 @@ static void print_bad(FILE *fp,
         fprintf(fp, "bonds:");
         for (i = 0; i < nrbond; i++)
         {
-            fprintf(fp, " %u-%u (%g)",
+            fprintf(fp, " %d-%d (%g)",
                     bonds[i].AI+1, bonds[i].AJ+1, bonds[i].c);
         }
         fprintf(fp, "\n");
@@ -301,7 +299,7 @@ static void print_bad(FILE *fp,
         fprintf(fp, "angles:");
         for (i = 0; i < nrang; i++)
         {
-            fprintf(fp, " %u-%u-%u (%g)",
+            fprintf(fp, " %d-%d-%d (%g)",
                     angles[i].AI+1, angles[i].AJ+1,
                     angles[i].AK+1, angles[i].c);
         }
@@ -312,7 +310,7 @@ static void print_bad(FILE *fp,
         fprintf(fp, "idihs:");
         for (i = 0; i < nridih; i++)
         {
-            fprintf(fp, " %u-%u-%u-%u (%g)",
+            fprintf(fp, " %d-%d-%d-%d (%g)",
                     idihs[i].AI+1, idihs[i].AJ+1,
                     idihs[i].AK+1, idihs[i].AL+1, idihs[i].c);
         }
@@ -424,7 +422,7 @@ static gmx_bool calc_vsite3_param(gpp_atomtype_t atype,
         int i;
         for (i = 0; i < 4; i++)
         {
-            fprintf(debug, "atom %u type %s ",
+            fprintf(debug, "atom %d type %s ",
                     param->a[i]+1,
                     get_atomtype_name_AB(&at->atom[param->a[i]], atype));
         }
@@ -495,7 +493,7 @@ static gmx_bool calc_vsite3_param(gpp_atomtype_t atype,
 
     if (debug)
     {
-        fprintf(debug, "params for vsite3 %u: %g %g\n",
+        fprintf(debug, "params for vsite3 %d: %g %g\n",
                 param->AI+1, param->C0, param->C1);
     }
 
@@ -529,7 +527,7 @@ static gmx_bool calc_vsite3fd_param(t_param *param,
 
     if (debug)
     {
-        fprintf(debug, "params for vsite3fd %u: %g %g\n",
+        fprintf(debug, "params for vsite3fd %d: %g %g\n",
                 param->AI+1, param->C0, param->C1);
     }
     return bError;
@@ -564,7 +562,7 @@ static gmx_bool calc_vsite3fad_param(t_param *param,
 
     if (debug)
     {
-        fprintf(debug, "params for vsite3fad %u: %g %g\n",
+        fprintf(debug, "params for vsite3fad %d: %g %g\n",
                 param->AI+1, param->C0, param->C1);
     }
     return bError;
@@ -591,7 +589,7 @@ static gmx_bool calc_vsite3out_param(gpp_atomtype_t atype,
         int i;
         for (i = 0; i < 4; i++)
         {
-            fprintf(debug, "atom %u type %s ",
+            fprintf(debug, "atom %d type %s ",
                     param->a[i]+1, get_atomtype_name_AB(&at->atom[param->a[i]], atype));
         }
         fprintf(debug, "\n");
@@ -676,7 +674,7 @@ static gmx_bool calc_vsite3out_param(gpp_atomtype_t atype,
     }
     if (debug)
     {
-        fprintf(debug, "params for vsite3out %u: %g %g %g\n",
+        fprintf(debug, "params for vsite3out %d: %g %g %g\n",
                 param->AI+1, param->C0, param->C1, param->C2);
     }
     return bError;
@@ -734,7 +732,7 @@ static gmx_bool calc_vsite4fd_param(t_param *param,
         param->C2 = -bij;
         if (debug)
         {
-            fprintf(debug, "params for vsite4fd %u: %g %g %g\n",
+            fprintf(debug, "params for vsite4fd %d: %g %g %g\n",
                     param->AI+1, param->C0, param->C1, param->C2);
         }
     }
@@ -797,7 +795,7 @@ calc_vsite4fdn_param(t_param *param,
 
         if (debug)
         {
-            fprintf(debug, "params for vsite4fdn %u: %g %g %g\n",
+            fprintf(debug, "params for vsite4fdn %d: %g %g %g\n",
                     param->AI+1, param->C0, param->C1, param->C2);
         }
     }
@@ -831,10 +829,17 @@ int set_vsites(gmx_bool bVerbose, t_atoms *atoms, gpp_atomtype_t atype,
 
     for (ftype = 0; (ftype < F_NRE); ftype++)
     {
-        if ((interaction_function[ftype].flags & IF_VSITE) && ftype != F_VSITEN)
+        if (interaction_function[ftype].flags & IF_VSITE)
         {
-            nrset   = 0;
             nvsite += plist[ftype].nr;
+
+            if (ftype == F_VSITEN)
+            {
+                /* We don't calculate parameters for VSITEN */
+                continue;
+            }
+
+            nrset = 0;
             for (i = 0; (i < plist[ftype].nr); i++)
             {
                 /* check if all parameters are set */
@@ -868,7 +873,7 @@ int set_vsites(gmx_bool bVerbose, t_atoms *atoms, gpp_atomtype_t atype,
                     if (debug)
                     {
                         fprintf(debug, "Found %d bonds, %d angles and %d idihs "
-                                "for virtual site %u (%s)\n", nrbond, nrang, nridih,
+                                "for virtual site %d (%s)\n", nrbond, nrang, nridih,
                                 plist[ftype].param[i].AI+1,
                                 interaction_function[ftype].longname);
                         print_bad(debug, nrbond, bonds, nrang, angles, nridih, idihs);
@@ -1000,7 +1005,7 @@ static void check_vsite_constraints(t_params *plist,
             atom = ps->param[i].a[k];
             if (vsite_type[atom] != NOTSET)
             {
-                fprintf(stderr, "ERROR: Cannot have constraint (%u-%u) with virtual site (%u)\n",
+                fprintf(stderr, "ERROR: Cannot have constraint (%d-%d) with virtual site (%d)\n",
                         ps->param[i].AI+1, ps->param[i].AJ+1, atom+1);
                 n++;
             }
@@ -1015,10 +1020,9 @@ static void check_vsite_constraints(t_params *plist,
 static void clean_vsite_bonds(t_params *plist, t_pindex pindex[],
                               int cftype, int vsite_type[])
 {
-    int          ftype, i, j, parnr, k, l, m, n, nvsite, nOut, kept_i, vsnral, vsitetype;
+    int          ftype, i, j, parnr, k, l, m, n, nvsite, nOut, kept_i, vsitetype;
     int          nconverted, nremoved;
-    atom_id      atom, oatom, constr, at1, at2;
-    atom_id      vsiteatoms[MAXATOMLIST];
+    atom_id      atom, oatom, at1, at2;
     gmx_bool     bKeep, bRemove, bUsed, bPresent, bThisFD, bThisOUT, bAllFD, bFirstTwo;
     t_params    *ps;
 
@@ -1028,13 +1032,15 @@ static void clean_vsite_bonds(t_params *plist, t_pindex pindex[],
     }
 
     ps         = &(plist[cftype]);
-    vsnral     = 0;
     kept_i     = 0;
     nconverted = 0;
     nremoved   = 0;
     nOut       = 0;
     for (i = 0; (i < ps->nr); i++) /* for all bonds in the plist */
     {
+        int            vsnral      = 0;
+        const atom_id *first_atoms = NULL;
+
         bKeep   = FALSE;
         bRemove = FALSE;
         bAllFD  = TRUE;
@@ -1042,21 +1048,14 @@ static void clean_vsite_bonds(t_params *plist, t_pindex pindex[],
         nvsite = 0;
         if (debug)
         {
-            fprintf(debug, "constr %u %u:", ps->param[i].AI+1, ps->param[i].AJ+1);
+            fprintf(debug, "constr %d %d:", ps->param[i].AI+1, ps->param[i].AJ+1);
         }
         for (k = 0; (k < 2) && !bKeep && !bRemove; k++)
         {
             /* for all atoms in the bond */
             atom = ps->param[i].a[k];
-            if (vsite_type[atom] != NOTSET)
+            if (vsite_type[atom] != NOTSET && vsite_type[atom] != F_VSITEN)
             {
-                if (debug)
-                {
-                    fprintf(debug, " d%d[%d: %d %d %d]", k, atom+1,
-                            plist[pindex[atom].ftype].param[pindex[atom].parnr].AJ+1,
-                            plist[pindex[atom].ftype].param[pindex[atom].parnr].AK+1,
-                            plist[pindex[atom].ftype].param[pindex[atom].parnr].AL+1);
-                }
                 nvsite++;
                 bThisFD = ( (pindex[atom].ftype == F_VSITE3FD ) ||
                             (pindex[atom].ftype == F_VSITE3FAD) ||
@@ -1073,6 +1072,7 @@ static void clean_vsite_bonds(t_params *plist, t_pindex pindex[],
                     }
                     oatom = ps->param[i].a[1-k]; /* the other atom */
                     if (vsite_type[oatom] == NOTSET &&
+                        vsite_type[oatom] != F_VSITEN &&
                         oatom == plist[pindex[atom].ftype].param[pindex[atom].parnr].AJ)
                     {
                         /* if the other atom isn't a vsite, and it is AI */
@@ -1089,31 +1089,36 @@ static void clean_vsite_bonds(t_params *plist, t_pindex pindex[],
                 }
                 if (!bRemove)
                 {
+                    /* TODO This fragment, and corresponding logic in
+                       clean_vsite_angles and clean_vsite_dihs should
+                       be refactored into a common function */
                     if (nvsite == 1)
                     {
                         /* if this is the first vsite we encounter then
                            store construction atoms */
-                        vsnral = NRAL(pindex[atom].ftype)-1;
-                        for (m = 0; (m < vsnral); m++)
-                        {
-                            vsiteatoms[m] =
-                                plist[pindex[atom].ftype].param[pindex[atom].parnr].a[m+1];
-                        }
+                        /* TODO This would be nicer to implement with
+                           a C++ "vector view" class" with an
+                           STL-container-like interface. */
+                        vsnral      = NRAL(pindex[atom].ftype) - 1;
+                        first_atoms = plist[pindex[atom].ftype].param[pindex[atom].parnr].a + 1;
                     }
                     else
                     {
+                        assert(vsnral != 0);
+                        assert(first_atoms != NULL);
                         /* if it is not the first then
                            check if this vsite is constructed from the same atoms */
                         if (vsnral == NRAL(pindex[atom].ftype)-1)
                         {
                             for (m = 0; (m < vsnral) && !bKeep; m++)
                             {
+                                const atom_id *atoms;
+
                                 bPresent = FALSE;
-                                constr   =
-                                    plist[pindex[atom].ftype].param[pindex[atom].parnr].a[m+1];
+                                atoms    = plist[pindex[atom].ftype].param[pindex[atom].parnr].a + 1;
                                 for (n = 0; (n < vsnral) && !bPresent; n++)
                                 {
-                                    if (constr == vsiteatoms[n])
+                                    if (atoms[m] == first_atoms[n])
                                     {
                                         bPresent = TRUE;
                                     }
@@ -1157,17 +1162,22 @@ static void clean_vsite_bonds(t_params *plist, t_pindex pindex[],
                 bKeep = TRUE;
             }
 
+            /* TODO This loop and the corresponding loop in
+               check_vsite_angles should be refactored into a common
+               function */
             /* check if all non-vsite atoms are used in construction: */
             bFirstTwo = TRUE;
             for (k = 0; (k < 2) && !bKeep; k++) /* for all atoms in the bond */
             {
                 atom = ps->param[i].a[k];
-                if (vsite_type[atom] == NOTSET)
+                if (vsite_type[atom] == NOTSET && vsite_type[atom] != F_VSITEN)
                 {
                     bUsed = FALSE;
                     for (m = 0; (m < vsnral) && !bUsed; m++)
                     {
-                        if (atom == vsiteatoms[m])
+                        assert(first_atoms != NULL);
+
+                        if (atom == first_atoms[m])
                         {
                             bUsed     = TRUE;
                             bFirstTwo = bFirstTwo && m < 2;
@@ -1186,11 +1196,15 @@ static void clean_vsite_bonds(t_params *plist, t_pindex pindex[],
 
             if (!( bAllFD && bFirstTwo ) )
             {
-                /* check if all constructing atoms are constrained together */
+                /* Two atom bonded interactions include constraints.
+                 * We need to remove constraints between vsite pairs that have
+                 * a fixed distance due to being constructed from the same
+                 * atoms, since this can be numerically unstable.
+                 */
                 for (m = 0; m < vsnral && !bKeep; m++) /* all constr. atoms */
                 {
-                    at1      = vsiteatoms[m];
-                    at2      = vsiteatoms[(m+1) % vsnral];
+                    at1      = first_atoms[m];
+                    at2      = first_atoms[(m+1) % vsnral];
                     bPresent = FALSE;
                     for (ftype = 0; ftype < F_NRE; ftype++)
                     {
@@ -1272,17 +1286,18 @@ static void clean_vsite_angles(t_params *plist, t_pindex pindex[],
                                int cftype, int vsite_type[],
                                at2vsitecon_t *at2vc)
 {
-    int          i, j, parnr, k, l, m, n, nvsite, kept_i, vsnral, vsitetype;
-    atom_id      atom, constr, at1, at2;
-    atom_id      vsiteatoms[MAXATOMLIST];
+    int          i, j, parnr, k, l, m, n, nvsite, kept_i, vsitetype;
+    atom_id      atom, at1, at2;
     gmx_bool     bKeep, bUsed, bPresent, bAll3FAD, bFirstTwo;
     t_params    *ps;
 
     ps     = &(plist[cftype]);
-    vsnral = 0;
     kept_i = 0;
     for (i = 0; (i < ps->nr); i++) /* for all angles in the plist */
     {
+        int            vsnral      = 0;
+        const atom_id *first_atoms = NULL;
+
         bKeep    = FALSE;
         bAll3FAD = TRUE;
         /* check if all virtual sites are constructed from the same atoms */
@@ -1290,45 +1305,46 @@ static void clean_vsite_angles(t_params *plist, t_pindex pindex[],
         for (k = 0; (k < 3) && !bKeep; k++) /* for all atoms in the angle */
         {
             atom = ps->param[i].a[k];
-            if (vsite_type[atom] != NOTSET)
+            if (vsite_type[atom] != NOTSET && vsite_type[atom] != F_VSITEN)
             {
                 nvsite++;
                 bAll3FAD = bAll3FAD && (pindex[atom].ftype == F_VSITE3FAD);
                 if (nvsite == 1)
                 {
                     /* store construction atoms of first vsite */
-                    vsnral = NRAL(pindex[atom].ftype)-1;
-                    for (m = 0; (m < vsnral); m++)
-                    {
-                        vsiteatoms[m] =
-                            plist[pindex[atom].ftype].param[pindex[atom].parnr].a[m+1];
-                    }
+                    vsnral      = NRAL(pindex[atom].ftype) - 1;
+                    first_atoms = plist[pindex[atom].ftype].param[pindex[atom].parnr].a + 1;
                 }
                 else
-                /* check if this vsite is constructed from the same atoms */
-                if (vsnral == NRAL(pindex[atom].ftype)-1)
                 {
-                    for (m = 0; (m < vsnral) && !bKeep; m++)
+                    assert(vsnral != 0);
+                    assert(first_atoms != NULL);
+                    /* check if this vsite is constructed from the same atoms */
+                    if (vsnral == NRAL(pindex[atom].ftype)-1)
                     {
-                        bPresent = FALSE;
-                        constr   =
-                            plist[pindex[atom].ftype].param[pindex[atom].parnr].a[m+1];
-                        for (n = 0; (n < vsnral) && !bPresent; n++)
+                        for (m = 0; (m < vsnral) && !bKeep; m++)
                         {
-                            if (constr == vsiteatoms[n])
+                            const atom_id *atoms;
+
+                            bPresent = FALSE;
+                            atoms    = plist[pindex[atom].ftype].param[pindex[atom].parnr].a + 1;
+                            for (n = 0; (n < vsnral) && !bPresent; n++)
                             {
-                                bPresent = TRUE;
+                                if (atoms[m] == first_atoms[n])
+                                {
+                                    bPresent = TRUE;
+                                }
+                            }
+                            if (!bPresent)
+                            {
+                                bKeep = TRUE;
                             }
                         }
-                        if (!bPresent)
-                        {
-                            bKeep = TRUE;
-                        }
                     }
-                }
-                else
-                {
-                    bKeep = TRUE;
+                    else
+                    {
+                        bKeep = TRUE;
+                    }
                 }
             }
         }
@@ -1345,12 +1361,14 @@ static void clean_vsite_angles(t_params *plist, t_pindex pindex[],
         for (k = 0; (k < 3) && !bKeep; k++) /* for all atoms in the angle */
         {
             atom = ps->param[i].a[k];
-            if (vsite_type[atom] == NOTSET)
+            if (vsite_type[atom] == NOTSET && vsite_type[atom] != F_VSITEN)
             {
                 bUsed = FALSE;
                 for (m = 0; (m < vsnral) && !bUsed; m++)
                 {
-                    if (atom == vsiteatoms[m])
+                    assert(first_atoms != NULL);
+
+                    if (atom == first_atoms[m])
                     {
                         bUsed     = TRUE;
                         bFirstTwo = bFirstTwo && m < 2;
@@ -1368,8 +1386,8 @@ static void clean_vsite_angles(t_params *plist, t_pindex pindex[],
             /* check if all constructing atoms are constrained together */
             for (m = 0; m < vsnral && !bKeep; m++) /* all constr. atoms */
             {
-                at1      = vsiteatoms[m];
-                at2      = vsiteatoms[(m+1) % vsnral];
+                at1      = first_atoms[m];
+                at2      = first_atoms[(m+1) % vsnral];
                 bPresent = FALSE;
                 for (j = 0; j < at2vc[at1].nr; j++)
                 {
@@ -1412,11 +1430,11 @@ static void clean_vsite_dihs(t_params *plist, t_pindex pindex[],
     kept_i = 0;
     for (i = 0; (i < ps->nr); i++) /* for all dihedrals in the plist */
     {
-        int      ftype, parnr, k, l, m, n, nvsite;
-        int      vsnral = 0;            /* keep the compiler happy */
-        atom_id  atom, constr;
-        atom_id  vsiteatoms[4] = { 0 }; /* init to zero to make gcc4.8 happy */
-        gmx_bool bKeep, bUsed, bPresent;
+        int            ftype, parnr, k, l, m, n, nvsite;
+        int            vsnral      = 0;
+        const atom_id *first_atoms = NULL;
+        atom_id        atom;
+        gmx_bool       bKeep, bUsed, bPresent;
 
 
         bKeep = FALSE;
@@ -1425,40 +1443,39 @@ static void clean_vsite_dihs(t_params *plist, t_pindex pindex[],
         for (k = 0; (k < 4) && !bKeep; k++) /* for all atoms in the dihedral */
         {
             atom = ps->param[i].a[k];
-            if (vsite_type[atom] != NOTSET)
+            if (vsite_type[atom] != NOTSET && vsite_type[atom] != F_VSITEN)
             {
                 if (nvsite == 0)
                 {
                     /* store construction atoms of first vsite */
-                    vsnral = NRAL(pindex[atom].ftype)-1;
-                    assert(vsnral <= 4);
-                    for (m = 0; (m < vsnral); m++)
-                    {
-                        vsiteatoms[m] =
-                            plist[pindex[atom].ftype].param[pindex[atom].parnr].a[m+1];
-                    }
+                    vsnral      = NRAL(pindex[atom].ftype) - 1;
+                    first_atoms = plist[pindex[atom].ftype].param[pindex[atom].parnr].a + 1;
                     if (debug)
                     {
-                        fprintf(debug, "dih w. vsite: %u %u %u %u\n",
+                        fprintf(debug, "dih w. vsite: %d %d %d %d\n",
                                 ps->param[i].AI+1, ps->param[i].AJ+1,
                                 ps->param[i].AK+1, ps->param[i].AL+1);
-                        fprintf(debug, "vsite %u from: %u %u %u\n",
-                                atom+1, vsiteatoms[0]+1, vsiteatoms[1]+1, vsiteatoms[2]+1);
+                        fprintf(debug, "vsite %d from: %d %d %d\n",
+                                atom+1, first_atoms[0]+1, first_atoms[1]+1, first_atoms[2]+1);
                     }
                 }
                 else
                 {
+                    assert(vsnral != 0);
+                    assert(first_atoms != NULL);
+
                     /* check if this vsite is constructed from the same atoms */
                     if (vsnral == NRAL(pindex[atom].ftype)-1)
                     {
                         for (m = 0; (m < vsnral) && !bKeep; m++)
                         {
+                            const atom_id *atoms;
+
                             bPresent = FALSE;
-                            constr   =
-                                plist[pindex[atom].ftype].param[pindex[atom].parnr].a[m+1];
+                            atoms    = plist[pindex[atom].ftype].param[pindex[atom].parnr].a + 1;
                             for (n = 0; (n < vsnral) && !bPresent; n++)
                             {
-                                if (constr == vsiteatoms[n])
+                                if (atoms[m] == first_atoms[n])
                                 {
                                     bPresent = TRUE;
                                 }
@@ -1470,6 +1487,9 @@ static void clean_vsite_dihs(t_params *plist, t_pindex pindex[],
                         }
                     }
                 }
+                /* TODO clean_site_bonds and _angles do this increment
+                   at the top of the loop. Refactor this for
+                   consistency */
                 nvsite++;
             }
         }
@@ -1484,14 +1504,17 @@ static void clean_vsite_dihs(t_params *plist, t_pindex pindex[],
            construction of virtual sites. If so, keep it, if not throw away: */
         for (k = 0; (k < 4) && !bKeep; k++) /* for all atoms in the dihedral */
         {
+            assert(vsnral != 0);
+            assert(first_atoms != NULL);
+
             atom = ps->param[i].a[k];
-            if (vsite_type[atom] == NOTSET)
+            if (vsite_type[atom] == NOTSET && vsite_type[atom] != F_VSITEN)
             {
                 /* vsnral will be set here, we don't get here with nvsite==0 */
                 bUsed = FALSE;
                 for (m = 0; (m < vsnral) && !bUsed; m++)
                 {
-                    if (atom == vsiteatoms[m])
+                    if (atom == first_atoms[m])
                     {
                         bUsed = TRUE;
                     }
@@ -1501,7 +1524,7 @@ static void clean_vsite_dihs(t_params *plist, t_pindex pindex[],
                     bKeep = TRUE;
                     if (debug)
                     {
-                        fprintf(debug, "unused atom in dih: %u\n", atom+1);
+                        fprintf(debug, "unused atom in dih: %d\n", atom+1);
                     }
                 }
             }
@@ -1581,6 +1604,17 @@ void clean_vsite_bondeds(t_params *plist, int natoms, gmx_bool bRmVSiteBds)
         snew(pindex, natoms);
         for (ftype = 0; ftype < F_NRE; ftype++)
         {
+            /* Here we skip VSITEN. In neary all practical use cases this
+             * is not an issue, since VSITEN is intended for constructing
+             * additional interaction sites, not for replacing normal atoms
+             * with bonded interactions. Thus we do not expect constant
+             * bonded interactions. If VSITEN does get used with constant
+             * bonded interactions, these are not removed which only leads
+             * to very minor extra computation and constant energy.
+             * The only problematic case is onstraints between VSITEN
+             * constructions with fixed distance (which is anyhow useless).
+             * This will generate a fatal error in check_vsite_constraints.
+             */
             if ((interaction_function[ftype].flags & IF_VSITE) &&
                 ftype != F_VSITEN)
             {
@@ -1603,7 +1637,7 @@ void clean_vsite_bondeds(t_params *plist, int natoms, gmx_bool bRmVSiteBds)
             }
         }
 
-        /* remove things with vsite atoms */
+        /* remove interactions that include virtual sites */
         for (ftype = 0; ftype < F_NRE; ftype++)
         {
             if ( ( ( interaction_function[ftype].flags & IF_BOND ) && bRmVSiteBds ) ||
@@ -1623,7 +1657,7 @@ void clean_vsite_bondeds(t_params *plist, int natoms, gmx_bool bRmVSiteBds)
                 }
             }
         }
-        /* check if we have constraints left with virtual sites in them */
+        /* check that no remaining constraints include virtual sites */
         for (ftype = 0; ftype < F_NRE; ftype++)
         {
             if (interaction_function[ftype].flags & IF_CONSTRAINT)
