@@ -3,7 +3,7 @@
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
  * Copyright (c) 2001-2008, The GROMACS development team.
- * Copyright (c) 2013,2014, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2015, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -34,40 +34,35 @@
  * To help us fund GROMACS development, we humbly ask that you cite
  * the research papers on the package. Check out http://www.gromacs.org.
  */
-#include "x2top.h"
+#include "gmxpre.h"
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "x2top.h"
 
 #include <assert.h>
 
-#include "copyrite.h"
-#include "gromacs/math/utilities.h"
-#include "macros.h"
-#include "bondf.h"
-#include "gromacs/fileio/gmxfio.h"
-#include "gromacs/utility/cstringutil.h"
-#include "gromacs/utility/smalloc.h"
-#include "sysstuff.h"
-#include "gromacs/fileio/confio.h"
-#include "physics.h"
 #include "gromacs/commandline/pargs.h"
-#include "vec.h"
-#include "gromacs/math/3dview.h"
-#include "txtdump.h"
-#include "readinp.h"
-#include "names.h"
-#include "toppush.h"
-#include "pdb2top.h"
-#include "gen_ad.h"
-#include "gpp_nextnb.h"
-#include "vec.h"
-#include "atomprop.h"
-#include "hackblock.h"
-#include "nm2type.h"
-
-#include "gmx_fatal.h"
+#include "gromacs/fileio/confio.h"
+#include "gromacs/fileio/gmxfio.h"
+#include "gromacs/gmxpreprocess/gen_ad.h"
+#include "gromacs/gmxpreprocess/gpp_nextnb.h"
+#include "gromacs/gmxpreprocess/hackblock.h"
+#include "gromacs/gmxpreprocess/nm2type.h"
+#include "gromacs/gmxpreprocess/pdb2top.h"
+#include "gromacs/gmxpreprocess/toppush.h"
+#include "gromacs/legacyheaders/copyrite.h"
+#include "gromacs/legacyheaders/macros.h"
+#include "gromacs/legacyheaders/names.h"
+#include "gromacs/legacyheaders/readinp.h"
+#include "gromacs/legacyheaders/txtdump.h"
+#include "gromacs/listed-forces/bonded.h"
+#include "gromacs/math/units.h"
+#include "gromacs/math/utilities.h"
+#include "gromacs/math/vec.h"
+#include "gromacs/pbcutil/pbc.h"
+#include "gromacs/topology/symtab.h"
+#include "gromacs/utility/cstringutil.h"
+#include "gromacs/utility/fatalerror.h"
+#include "gromacs/utility/smalloc.h"
 
 char atp[7] = "HCNOSX";
 #define NATP (asize(atp)-1)
@@ -418,8 +413,8 @@ int gmx_x2top(int argc, char *argv[])
         "[THISMODULE] generates a primitive topology from a coordinate file.",
         "The program assumes all hydrogens are present when defining",
         "the hybridization from the atom name and the number of bonds.",
-        "The program can also make an [TT].rtp[tt] entry, which you can then add",
-        "to the [TT].rtp[tt] database.[PAR]",
+        "The program can also make an [REF].rtp[ref] entry, which you can then add",
+        "to the [REF].rtp[ref] database.[PAR]",
         "When [TT]-param[tt] is set, equilibrium distances and angles",
         "and force constants will be printed in the topology for all",
         "interactions. The equilibrium distances and angles are taken",
@@ -502,7 +497,7 @@ int gmx_x2top(int argc, char *argv[])
         { "-pbc",    FALSE, etBOOL, {&bPBC},
           "Use periodic boundary conditions." },
         { "-pdbq",  FALSE, etBOOL, {&bUsePDBcharge},
-          "Use the B-factor supplied in a [TT].pdb[tt] file for the atomic charges" },
+          "Use the B-factor supplied in a [REF].pdb[ref] file for the atomic charges" },
         { "-param", FALSE, etBOOL, {&bParam},
           "Print parameters in the output" },
         { "-round",  FALSE, etBOOL, {&bRound},
@@ -542,7 +537,7 @@ int gmx_x2top(int argc, char *argv[])
     bOPLS = (strcmp(forcefield, "oplsaa") == 0);
 
 
-    mymol.name = strdup(molnm);
+    mymol.name = gmx_strdup(molnm);
     mymol.nr   = 1;
 
     /* Init parameter lists */
@@ -635,10 +630,10 @@ int gmx_x2top(int argc, char *argv[])
         dump_hybridization(debug, atoms, nbonds);
     }
     close_symtab(&symtab);
-    free(mymol.name);
+    sfree(mymol.name);
 
     printf("\nWARNING: topologies generated by %s can not be trusted at face value.\n",
-           ShortProgram());
+           output_env_get_program_display_name(oenv));
     printf("         Please verify atomtypes and charges by comparison to other\n");
     printf("         topologies.\n");
 
