@@ -1,6 +1,6 @@
 #include <math.h>
 
-#include "types/simple.h"
+#include "gromacs/utility/real.h"
 
 #include "../gmx_blas.h"
 
