@@ -1,6 +1,6 @@
 #include <ctype.h>
 #include "../gmx_lapack.h"
-#include "types/simple.h"
+#include "gromacs/utility/real.h"
 
 void
 F77_FUNC(dorml2,DORML2)(const char *side,
