@@ -34,35 +34,30 @@
  * To help us fund GROMACS development, we humbly ask that you cite
  * the research papers on the package. Check out http://www.gromacs.org.
  */
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "gmxpre.h"
 
 #include <math.h>
 #include <string.h>
 
-#include "typedefs.h"
-#include "gromacs/utility/smalloc.h"
-#include "genborn.h"
-#include "vec.h"
+#include "gromacs/domdec/domdec.h"
 #include "gromacs/fileio/pdbio.h"
-#include "names.h"
-#include "physics.h"
-#include "domdec.h"
-#include "network.h"
-#include "gmx_fatal.h"
-#include "mtop_util.h"
-#include "genborn.h"
-
+#include "gromacs/legacyheaders/genborn.h"
+#include "gromacs/legacyheaders/names.h"
+#include "gromacs/legacyheaders/network.h"
+#include "gromacs/legacyheaders/typedefs.h"
+#include "gromacs/math/units.h"
+#include "gromacs/math/vec.h"
+#include "gromacs/utility/fatalerror.h"
 #include "gromacs/utility/gmxmpi.h"
+#include "gromacs/utility/smalloc.h"
 
 /* Only compile this file if SSE2 intrinsics are available */
 #if 0 && defined (GMX_SIMD_X86_SSE2_OR_HIGHER)
-#include <gmx_sse2_double.h>
-#include <emmintrin.h>
-
 #include "genborn_sse2_double.h"
 
+#include <emmintrin.h>
+#include <gmx_sse2_double.h>
+
 int
 calc_gb_rad_still_sse2_double(t_commrec *cr, t_forcerec *fr,
                               int natoms, gmx_localtop_t *top,
