@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2012,2013,2014, by the GROMACS development team, led by
+ * Copyright (c) 2012,2013,2014,2015, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -39,6 +39,8 @@
  * \author Teemu Murtola <teemu.murtola@gmail.com>
  * \ingroup module_onlinehelp
  */
+#include "gmxpre.h"
+
 #include "gromacs/onlinehelp/helpmanager.h"
 
 #include <string>
@@ -100,10 +102,10 @@ TEST_F(HelpManagerTest, HandlesRootTopic)
 TEST_F(HelpManagerTest, HandlesSubTopics)
 {
     MockHelpTopic &first =
-        rootTopic_.addSubTopic("first", "First topic", "First topic text");
+        rootTopic_.addSubTopic("first", "First topic", NULL);
     MockHelpTopic &firstSub =
-        first.addSubTopic("firstsub", "First subtopic", "First subtopic text");
-    rootTopic_.addSubTopic("second", "Second topic", "Second topic text");
+        first.addSubTopic("firstsub", "First subtopic", NULL);
+    rootTopic_.addSubTopic("second", "Second topic", NULL);
 
     using ::testing::_;
     EXPECT_CALL(firstSub, writeHelp(_));
@@ -115,9 +117,9 @@ TEST_F(HelpManagerTest, HandlesSubTopics)
 TEST_F(HelpManagerTest, HandlesInvalidTopics)
 {
     MockHelpTopic &first =
-        rootTopic_.addSubTopic("first", "First topic", "First topic text");
-    first.addSubTopic("firstsub", "First subtopic", "First subtopic text");
-    rootTopic_.addSubTopic("second", "Second topic", "Second topic text");
+        rootTopic_.addSubTopic("first", "First topic", NULL);
+    first.addSubTopic("firstsub", "First subtopic", NULL);
+    rootTopic_.addSubTopic("second", "Second topic", NULL);
 
     ASSERT_THROW_GMX(manager_.enterTopic("unknown"), gmx::InvalidInputError);
     ASSERT_NO_THROW_GMX(manager_.enterTopic("first"));
