@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2009,2010,2011,2012,2013, by the GROMACS development team, led by
+ * Copyright (c) 2009,2010,2011,2012,2013,2014,2015, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -36,11 +36,10 @@
  * \brief API for neighborhood searching for analysis.
  *
  * The main part of the API is the class gmx::AnalysisNeighborhood.
- * See the class documentation for usage.
+ * See \ref page_analysisnbsearch for an overview.
  *
  * The classes within this file can be used independently of the other parts
- * of the library.
- * The library also uses the classes internally.
+ * of the selection module.
  *
  * \author Teemu Murtola <teemu.murtola@gmail.com>
  * \inpublicapi
@@ -49,15 +48,19 @@
 #ifndef GMX_SELECTION_NBSEARCH_H
 #define GMX_SELECTION_NBSEARCH_H
 
+#include <vector>
+
 #include <boost/shared_ptr.hpp>
 
-#include "../legacyheaders/typedefs.h"
-#include "../utility/common.h"
-#include "../utility/gmxassert.h"
+#include "gromacs/math/vec.h"
+#include "gromacs/math/vectypes.h"
+#include "gromacs/utility/arrayref.h"
+#include "gromacs/utility/classhelpers.h"
+#include "gromacs/utility/gmxassert.h"
+#include "gromacs/utility/real.h"
 
-#include "indexutil.h"
-
-struct gmx_ana_pos_t;
+struct t_blocka;
+struct t_pbc;
 
 namespace gmx
 {
@@ -107,16 +110,55 @@ class AnalysisNeighborhoodPositions
          * to methods that accept positions.
          */
         AnalysisNeighborhoodPositions(const rvec &x)
-            : count_(1), index_(-1), x_(&x)
+            : count_(1), index_(-1), x_(&x), exclusionIds_(NULL), indices_(NULL)
         {
         }
         /*! \brief
          * Initializes positions from an array of position vectors.
          */
         AnalysisNeighborhoodPositions(const rvec x[], int count)
-            : count_(count), index_(-1), x_(x)
+            : count_(count), index_(-1), x_(x), exclusionIds_(NULL), indices_(NULL)
         {
         }
+        /*! \brief
+         * Initializes positions from a vector of position vectors.
+         */
+        AnalysisNeighborhoodPositions(const std::vector<RVec> &x)
+            : count_(x.size()), index_(-1), x_(as_rvec_array(&x[0])),
+              exclusionIds_(NULL), indices_(NULL)
+        {
+        }
+
+        /*! \brief
+         * Sets indices to use for mapping exclusions to these positions.
+         *
+         * The exclusion IDs can always be set, but they are ignored unless
+         * actual exclusions have been set with
+         * AnalysisNeighborhood::setTopologyExclusions().
+         */
+        AnalysisNeighborhoodPositions &
+        exclusionIds(ConstArrayRef<int> ids)
+        {
+            GMX_ASSERT(static_cast<int>(ids.size()) == count_,
+                       "Exclusion id array should match the number of positions");
+            exclusionIds_ = ids.data();
+            return *this;
+        }
+        /*! \brief
+         * Sets indices that select a subset of all positions from the array.
+         *
+         * If called, selected positions from the array of positions passed to
+         * the constructor is used instead of the whole array.
+         * All returned indices from AnalysisNeighborhoodPair objects are
+         * indices to the \p indices array passed here.
+         */
+        AnalysisNeighborhoodPositions &
+        indexed(ConstArrayRef<int> indices)
+        {
+            count_   = indices.size();
+            indices_ = indices.data();
+            return *this;
+        }
 
         /*! \brief
          * Selects a single position to use from an array.
@@ -126,6 +168,9 @@ class AnalysisNeighborhoodPositions
          * In contrast to the AnalysisNeighborhoodPositions(const rvec &)
          * constructor, AnalysisNeighborhoodPair objects return \p index
          * instead of zero.
+         *
+         * If used together with indexed(), \p index references the index array
+         * passed to indexed() instead of the position array.
          */
         AnalysisNeighborhoodPositions &selectSingleFromArray(int index)
         {
@@ -138,6 +183,8 @@ class AnalysisNeighborhoodPositions
         int                     count_;
         int                     index_;
         const rvec             *x_;
+        const int              *exclusionIds_;
+        const int              *indices_;
 
         //! To access the positions for initialization.
         friend class internal::AnalysisNeighborhoodSearchImpl;
@@ -148,11 +195,7 @@ class AnalysisNeighborhoodPositions
 /*! \brief
  * Neighborhood searching for analysis tools.
  *
- * This class implements neighborhood searching routines for analysis tools.
- * The emphasis is in flexibility and ease of use; one main driver is to have
- * a common implementation of grid-based searching to avoid replicating this in
- * multiple tools (and to make more tools take advantage of the significant
- * performance improvement this allows).
+ * See \ref page_analysisnbsearch for an overview.
  *
  * To use the search, create an object of this type, call setCutoff() to
  * initialize it, and then repeatedly call initSearch() to start a search with
@@ -168,12 +211,8 @@ class AnalysisNeighborhoodPositions
  * a single thread.
  *
  * \todo
- * Support for exclusions.
- * The 4.5/4.6 C API had very low-level support for exclusions, which was not
- * very convenient to use, and hadn't been tested much.  The internal code that
- * it used to do the exclusion during the search itself is still there, but it
- * needs more thought on what would be a convenient way to initialize it.
- * Can be implemented once there is need for it in some calling code.
+ * Generalize the exclusion machinery to make it easier to use for other cases
+ * than atom-atom exclusions from the topology.
  *
  * \inpublicapi
  * \ingroup module_selection
@@ -197,7 +236,7 @@ class AnalysisNeighborhood
         ~AnalysisNeighborhood();
 
         /*! \brief
-         * Set cutoff distance for the neighborhood searching.
+         * Sets cutoff distance for the neighborhood searching.
          *
          * \param[in]  cutoff Cutoff distance for the search
          *   (<=0 stands for no cutoff).
@@ -208,6 +247,34 @@ class AnalysisNeighborhood
          * Does not throw.
          */
         void setCutoff(real cutoff);
+        /*! \brief
+         * Sets the search to only happen in the XY plane.
+         *
+         * Z component of the coordinates is not used in the searching,
+         * and returned distances are computed in the XY plane.
+         * Only boxes with the third box vector parallel to the Z axis are
+         * currently implemented.
+         *
+         * Does not throw.
+         */
+        void setXYMode(bool bXY);
+        /*! \brief
+         * Sets atom exclusions from a topology.
+         *
+         * The \p excls structure specifies the exclusions from test positions
+         * to reference positions, i.e., a block starting at `excls->index[i]`
+         * specifies the exclusions for test position `i`, and the indices in
+         * `excls->a` are indices of the reference positions.  If `excls->nr`
+         * is smaller than a test position id, then such test positions do not
+         * have any exclusions.
+         * It is assumed that the indices within a block of indices in
+         * `excls->a` is ascending.
+         *
+         * Does not throw.
+         *
+         * \see AnalysisNeighborhoodPositions::exclusionIds()
+         */
+        void setTopologyExclusions(const t_blocka *excls);
         /*! \brief
          * Sets the algorithm to use for searching.
          *
@@ -258,11 +325,16 @@ class AnalysisNeighborhoodPair
 {
     public:
         //! Initializes an invalid pair.
-        AnalysisNeighborhoodPair() : refIndex_(-1), testIndex_(0) {}
-        //! Initializes a pair object with the given data.
-        AnalysisNeighborhoodPair(int refIndex, int testIndex)
-            : refIndex_(refIndex), testIndex_(testIndex)
+        AnalysisNeighborhoodPair() : refIndex_(-1), testIndex_(0), distance2_(0.0)
         {
+            clear_rvec(dx_);
+        }
+        //! Initializes a pair object with the given data.
+        AnalysisNeighborhoodPair(int refIndex, int testIndex, real distance2,
+                                 const rvec dx)
+            : refIndex_(refIndex), testIndex_(testIndex), distance2_(distance2)
+        {
+            copy_rvec(dx, dx_);
         }
 
         /*! \brief
@@ -295,10 +367,30 @@ class AnalysisNeighborhoodPair
             GMX_ASSERT(isValid(), "Accessing invalid object");
             return testIndex_;
         }
+        /*! \brief
+         * Returns the squared distance between the pair of positions.
+         */
+        real distance2() const
+        {
+            GMX_ASSERT(isValid(), "Accessing invalid object");
+            return distance2_;
+        }
+        /*! \brief
+         * Returns the shortest vector between the pair of positions.
+         *
+         * The vector is from the test position to the reference position.
+         */
+        const rvec &dx() const
+        {
+            GMX_ASSERT(isValid(), "Accessing invalid object");
+            return dx_;
+        }
 
     private:
         int                     refIndex_;
         int                     testIndex_;
+        real                    distance2_;
+        rvec                    dx_;
 };
 
 /*! \brief
