@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2010,2011,2012,2013,2014, by the GROMACS development team, led by
+ * Copyright (c) 2010,2011,2012,2013,2014,2015, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -44,10 +44,10 @@
 
 #include <string>
 
-#include "../options/optionstoragetemplate.h"
-#include "selection.h"
-#include "selectionenums.h"
-#include "selectionoption.h"
+#include "gromacs/options/optionstoragetemplate.h"
+#include "gromacs/selection/selection.h"
+#include "gromacs/selection/selectionenums.h"
+#include "gromacs/selection/selectionoption.h"
 
 namespace gmx
 {
@@ -69,16 +69,15 @@ class SelectionOptionStorage : public OptionStorageTemplate<Selection>
          * Initializes the storage from option settings.
          *
          * \param[in] settings   Storage settings.
+         * \param     manager    Manager for this object.
          */
-        SelectionOptionStorage(const SelectionOption &settings);
+        SelectionOptionStorage(const SelectionOption  &settings,
+                               SelectionOptionManager *manager);
 
         virtual OptionInfo &optionInfo() { return info_; }
         virtual std::string typeString() const { return "selection"; }
         virtual std::string formatSingleValue(const Selection &value) const;
 
-        //! \copydoc SelectionOptionInfo::setManager()
-        void setManager(SelectionOptionManager *manager);
-
         /*! \brief
          * Adds selections to the storage.
          *
@@ -102,6 +101,11 @@ class SelectionOptionStorage : public OptionStorageTemplate<Selection>
         // Required to access the number of values in selection requests.
         // See SelectionCollection::Impl.
         using MyBase::maxValueCount;
+        //! Whether the option allows only atom-valued selections.
+        bool allowsOnlyAtoms() const
+        {
+            return selectionFlags_.test(efSelection_OnlyAtoms);
+        }
         //! \copydoc SelectionOptionInfo::setValueCount()
         void setAllowedValueCount(int count);
         /*! \brief
@@ -127,7 +131,7 @@ class SelectionOptionStorage : public OptionStorageTemplate<Selection>
         virtual void processAll();
 
         SelectionOptionInfo     info_;
-        SelectionOptionManager *manager_;
+        SelectionOptionManager &manager_;
         std::string             defaultText_;
         SelectionFlags          selectionFlags_;
 };
