@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2009,2010,2011,2012,2013,2014, by the GROMACS development team, led by
+ * Copyright (c) 2009,2010,2011,2012,2013,2014,2015, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -39,12 +39,14 @@
  * \author Teemu Murtola <teemu.murtola@gmail.com>
  * \ingroup module_selection
  */
+#include "gmxpre.h"
+
+#include "selelem.h"
+
 #include <cstring>
 
 #include "gromacs/selection/indexutil.h"
-#include "gromacs/selection/poscalc.h"
 #include "gromacs/selection/position.h"
-#include "gromacs/selection/selmethod.h"
 #include "gromacs/utility/exceptions.h"
 #include "gromacs/utility/gmxassert.h"
 #include "gromacs/utility/smalloc.h"
@@ -52,7 +54,7 @@
 
 #include "keywords.h"
 #include "mempool.h"
-#include "selelem.h"
+#include "poscalc.h"
 #include "selmethod.h"
 
 /*!
@@ -130,7 +132,9 @@ _gmx_selelem_boolean_type_str(const gmx::SelectionTreeElement &sel)
 namespace gmx
 {
 
-SelectionTreeElement::SelectionTreeElement(e_selelem_t type)
+SelectionTreeElement::SelectionTreeElement(e_selelem_t              type,
+                                           const SelectionLocation &location)
+    : location_(location)
 {
     this->type       = type;
     this->flags      = (type != SEL_ROOT) ? SEL_ALLOCVAL : 0;
@@ -193,21 +197,13 @@ void SelectionTreeElement::freeValues()
                 break;
         }
     }
-    if (v.nalloc > 0)
+    _gmx_selvalue_free(&v);
+    if (type == SEL_SUBEXPRREF && u.param != NULL)
     {
-        if (v.type == POS_VALUE)
-        {
-            delete [] v.u.p;
-        }
-        else
-        {
-            sfree(v.u.ptr);
-        }
-    }
-    _gmx_selvalue_setstore(&v, NULL);
-    if (type == SEL_SUBEXPRREF && u.param)
-    {
-        u.param->val.u.ptr = NULL;
+        // TODO: This is now called from two different locations.
+        // It is likely that one of them is unnecessary, but that requires
+        // extra analysis to clarify.
+        _gmx_selelem_free_param(u.param);
     }
 }
 
@@ -307,18 +303,8 @@ void SelectionTreeElement::fillNameIfMissing(const char *selectionText)
         // Check whether the actual selection given was from an external group,
         // and if so, use the name of the external group.
         SelectionTreeElementPointer child = this->child;
-        while (child->type == SEL_MODIFIER)
-        {
-            if (!child->child || child->child->type != SEL_SUBEXPRREF
-                || !child->child->child)
-            {
-                break;
-            }
-            child = child->child->child;
-        }
-        if (child->type == SEL_EXPRESSION
-            && child->child && child->child->type == SEL_SUBEXPRREF
-            && child->child->child)
+        if (_gmx_selelem_is_default_kwpos(*child) && child->child
+            && child->child->type == SEL_SUBEXPRREF && child->child->child)
         {
             if (child->child->child->type == SEL_CONST
                 && child->child->child->v.type == GROUP_VALUE)
@@ -375,7 +361,8 @@ void SelectionTreeElement::checkUnsortedAtoms(
     }
 }
 
-void SelectionTreeElement::resolveIndexGroupReference(gmx_ana_indexgrps_t *grps)
+void SelectionTreeElement::resolveIndexGroupReference(
+        gmx_ana_indexgrps_t *grps, int natoms)
 {
     GMX_RELEASE_ASSERT(type == SEL_GROUPREF,
                        "Should only be called for index group reference elements");
@@ -420,6 +407,26 @@ void SelectionTreeElement::resolveIndexGroupReference(gmx_ana_indexgrps_t *grps)
     gmx_ana_index_set(&u.cgrp, foundGroup.isize, foundGroup.index,
                       foundGroup.nalloc_index);
     setName(foundName);
+
+    if (natoms > 0)
+    {
+        checkIndexGroup(natoms);
+    }
+}
+
+void SelectionTreeElement::checkIndexGroup(int natoms)
+{
+    GMX_RELEASE_ASSERT(type == SEL_CONST && v.type == GROUP_VALUE,
+                       "Should only be called for index group elements");
+    if (!gmx_ana_index_check_range(&u.cgrp, natoms))
+    {
+        std::string message = formatString(
+                    "Group '%s' cannot be used in selections, because it "
+                    "contains negative atom indices and/or references atoms "
+                    "not present (largest allowed atom index is %d).",
+                    name().c_str(), natoms);
+        GMX_THROW(InconsistentInputError(message));
+    }
 }
 
 } // namespace gmx
@@ -449,10 +456,22 @@ _gmx_selelem_set_vtype(const gmx::SelectionTreeElementPointer &sel,
     }
 }
 
-/*!
- * \param[in] method Method to free.
- * \param[in] mdata  Method data to free.
- */
+void
+_gmx_selelem_free_param(gmx_ana_selparam_t *param)
+{
+    if (param->val.u.ptr != NULL)
+    {
+        if (param->val.type == GROUP_VALUE)
+        {
+            for (int i = 0; i < param->val.nr; ++i)
+            {
+                gmx_ana_index_deinit(&param->val.u.g[i]);
+            }
+        }
+        _gmx_selvalue_free(&param->val);
+    }
+}
+
 void
 _gmx_selelem_free_method(gmx_ana_selmethod_t *method, void *mdata)
 {
@@ -470,37 +489,11 @@ _gmx_selelem_free_method(gmx_ana_selmethod_t *method, void *mdata)
      * access them. */
     if (method)
     {
-        int  i, j;
-
         /* Free the memory allocated for the parameters that are not managed
          * by the selection method itself. */
-        for (i = 0; i < method->nparams; ++i)
+        for (int i = 0; i < method->nparams; ++i)
         {
-            gmx_ana_selparam_t *param = &method->param[i];
-
-            if (param->val.u.ptr)
-            {
-                if (param->val.type == GROUP_VALUE)
-                {
-                    for (j = 0; j < param->val.nr; ++j)
-                    {
-                        gmx_ana_index_deinit(&param->val.u.g[j]);
-                    }
-                }
-                else if (param->val.type == POS_VALUE)
-                {
-                    if (param->val.nalloc > 0)
-                    {
-                        delete[] param->val.u.p;
-                        _gmx_selvalue_setstore(&param->val, NULL);
-                    }
-                }
-
-                if (param->val.nalloc > 0)
-                {
-                    sfree(param->val.u.ptr);
-                }
-            }
+            _gmx_selelem_free_param(&method->param[i]);
         }
         sfree(method->param);
         sfree(method);
@@ -609,7 +602,7 @@ _gmx_selelem_print_tree(FILE *fp, const gmx::SelectionTreeElement &sel,
         fprintf(fp, " eval=");
         _gmx_sel_print_evalfunc_name(fp, sel.evaluate);
     }
-    if (!(sel.flags & SEL_ALLOCVAL))
+    if (sel.v.nalloc < 0)
     {
         fprintf(fp, " (ext)");
     }
@@ -651,6 +644,23 @@ _gmx_selelem_print_tree(FILE *fp, const gmx::SelectionTreeElement &sel,
             fprintf(fp, "\n");
         }
     }
+    else if (sel.type == SEL_SUBEXPRREF && sel.u.param != NULL)
+    {
+        fprintf(fp, "%*c param", level*2+1, ' ');
+        if (sel.u.param->name != NULL)
+        {
+            fprintf(fp, " \"%s\"", sel.u.param->name);
+        }
+        if (sel.u.param->val.nalloc < 0)
+        {
+            fprintf(fp, " (ext)");
+        }
+        else
+        {
+            fprintf(fp, " nalloc: %d", sel.u.param->val.nalloc);
+        }
+        fprintf(fp, "\n");
+    }
 
     if (sel.cdata)
     {
