@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2009,2010,2011,2012,2014, by the GROMACS development team, led by
+ * Copyright (c) 2009,2010,2011,2012,2014,2015, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -39,12 +39,14 @@
  * \author Teemu Murtola <teemu.murtola@gmail.com>
  * \ingroup module_selection
  */
+#include "gmxpre.h"
+
+#include "selmethod.h"
+
 #include <ctype.h>
 #include <stdarg.h>
 
 #include "gromacs/legacyheaders/macros.h"
-
-#include "gromacs/selection/selmethod.h"
 #include "gromacs/utility/cstringutil.h"
 #include "gromacs/utility/exceptions.h"
 
@@ -152,12 +154,15 @@ static const t_register_method smtable_def[] = {
     {NULL,         &sm_altloc},
     {NULL,         &sm_occupancy},
     {NULL,         &sm_betafactor},
+    {"beta",       &sm_betafactor},
     {NULL,         &sm_x},
     {NULL,         &sm_y},
     {NULL,         &sm_z},
 
     {NULL,         &sm_distance},
+    {"dist",       &sm_distance},
     {NULL,         &sm_mindistance},
+    {"mindist",    &sm_mindistance},
     {NULL,         &sm_within},
     {NULL,         &sm_insolidangle},
     {NULL,         &sm_same},
@@ -384,7 +389,7 @@ check_params(FILE *fp, const char *name, int nparams, gmx_ana_selparam_t param[]
             continue;
         }
         /* Check that the name does not conflict with a method */
-        if (symtab.findSymbol(param[i].name, true))
+        if (symtab.findSymbol(param[i].name))
         {
             report_param_error(fp, name, param[i].name, "error: name conflicts with another method or a keyword");
             bOk = false;
