@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2014, by the GROMACS development team, led by
+ * Copyright (c) 2014,2015, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -36,7 +36,10 @@
 #ifndef GMX_SIMD_IMPL_X86_SSE2_H
 #define GMX_SIMD_IMPL_X86_SSE2_H
 
+#include "config.h"
+
 #include <math.h>
+
 #include <emmintrin.h>
 
 /* Set capabilities that can be inherited */
@@ -111,11 +114,11 @@
 #define gmx_simd_set_exponent_f   gmx_simd_set_exponent_f_sse2
 /* integer datatype corresponding to float: gmx_simd_fint32_t */
 #define gmx_simd_fint32_t         __m128i
-#define gmx_simd_load_fi(m)       _mm_load_si128((const __m128i *)m)
+#define gmx_simd_load_fi(m)       _mm_load_si128((const __m128i *)(m))
 #define gmx_simd_set1_fi          _mm_set1_epi32
-#define gmx_simd_store_fi(m, x)    _mm_store_si128((__m128i *)m, x)
-#define gmx_simd_loadu_fi(m)      _mm_loadu_si128((const __m128i *)m)
-#define gmx_simd_storeu_fi(m, x)   _mm_storeu_si128((__m128i *)m, x)
+#define gmx_simd_store_fi(m, x)    _mm_store_si128((__m128i *)(m), x)
+#define gmx_simd_loadu_fi(m)      _mm_loadu_si128((const __m128i *)(m))
+#define gmx_simd_storeu_fi(m, x)   _mm_storeu_si128((__m128i *)(m), x)
 #define gmx_simd_setzero_fi       _mm_setzero_si128
 #define gmx_simd_cvt_f2i          _mm_cvtps_epi32
 #define gmx_simd_cvtt_f2i         _mm_cvttps_epi32
@@ -195,11 +198,11 @@
 #define gmx_simd_set_exponent_d    gmx_simd_set_exponent_d_sse2
 /* integer datatype corresponding to double: gmx_simd_dint32_t */
 #define gmx_simd_dint32_t          __m128i
-#define gmx_simd_load_di(m)        _mm_loadl_epi64((const __m128i *)m)
+#define gmx_simd_load_di(m)        _mm_loadl_epi64((const __m128i *)(m))
 #define gmx_simd_set1_di           _mm_set1_epi32
-#define gmx_simd_store_di(m, x)     _mm_storel_epi64((__m128i *)m, x)
-#define gmx_simd_loadu_di(m)       _mm_loadl_epi64((const __m128i *)m)
-#define gmx_simd_storeu_di(m, x)    _mm_storel_epi64((__m128i *)m, x)
+#define gmx_simd_store_di(m, x)     _mm_storel_epi64((__m128i *)(m), x)
+#define gmx_simd_loadu_di(m)       _mm_loadl_epi64((const __m128i *)(m))
+#define gmx_simd_storeu_di(m, x)    _mm_storel_epi64((__m128i *)(m), x)
 #define gmx_simd_setzero_di        _mm_setzero_si128
 #define gmx_simd_cvt_d2i           _mm_cvtpd_epi32
 #define gmx_simd_cvtt_d2i          _mm_cvttpd_epi32
@@ -370,29 +373,6 @@ gmx_simd_reduce_d_sse2(__m128d a)
     return f;
 }
 
-/* Function to check whether SIMD operations have resulted in overflow */
-static int
-gmx_simd_check_and_reset_overflow(void)
-{
-    int MXCSR;
-    int sse_overflow;
-
-    MXCSR = _mm_getcsr();
-    /* The overflow flag is bit 3 in the register */
-    if (MXCSR & 0x0008)
-    {
-        sse_overflow = 1;
-        /* Set the overflow flag to zero */
-        MXCSR = MXCSR & 0xFFF7;
-        _mm_setcsr(MXCSR);
-    }
-    else
-    {
-        sse_overflow = 0;
-    }
-    return sse_overflow;
-}
-
 /* SSE2 is already 4-wide in single, so we just reuse float datatype for SIMD4.
  * SSE2 cannot do double-precision SIMD4.
  */
