@@ -1,7 +1,7 @@
 /*
  * This file is part of the GROMACS molecular simulation package.
  *
- * Copyright (c) 2014, by the GROMACS development team, led by
+ * Copyright (c) 2014,2015, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -32,15 +32,17 @@
  * To help us fund GROMACS development, we humbly ask that you cite
  * the research papers on the package. Check out http://www.gromacs.org.
  */
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "gmxpre.h"
+
+#include "gromacs/simd/simd_math.h"
+
+#include "config.h"
 
 #include <vector>
+
 #include "gromacs/math/utilities.h"
-#include "gromacs/simd/simd.h"
-#include "gromacs/simd/simd_math.h"
 #include "gromacs/options/basicoptions.h"
+#include "gromacs/simd/simd.h"
 
 #include "simd.h"
 
@@ -123,7 +125,8 @@ SimdMathTest::compareSimdMathFunction(const char * refFuncExpr, const char *simd
         {
             absDiff = fabs(vref[i]-vtst[i]);
             absOk   = absOk  && ( absDiff < absTol_ );
-            signOk  = signOk && ( vref[i]*vtst[i] >= 0 );
+            signOk  = signOk && ( (vref[i] >= 0 && vtst[i] >= 0) ||
+                                  (vref[i] <= 0 && vtst[i] <= 0));
 
             if (absDiff >= absTol_)
             {
@@ -400,7 +403,14 @@ TEST_F(SimdMathTest, gmxSimdCosR)
 /*! \brief Function wrapper for tan(x), with argument/return in default Gromacs precision */
 real ref_tan(real x)
 {
+#if (defined(__ibmxl__) || defined(__xlC__)) && !defined(GMX_DOUBLE)
+    /* xlC (both version 12 and 13) has some strange behaviour where tan(x) with a float argument incorrectly
+     * returns -0.0 for the argument 0.0 at -O3 optimization. tanf() seems to avoid it.
+     */
+    return tanf(x);
+#else
     return tan(x);
+#endif
 }
 
 TEST_F(SimdMathTest, gmxSimdTanR)
@@ -475,8 +485,15 @@ TEST_F(SimdMathTest, gmxSimdAtan2R)
 /*! \brief Evaluate reference version of PME force correction. */
 real ref_pmecorrF(real x)
 {
-    real y = sqrt(x);
-    return 2*exp(-x)/(sqrt(M_PI)*x) - gmx_erfd(y)/(x*y);
+    if (x != 0)
+    {
+        real y = sqrt(x);
+        return 2*exp(-x)/(sqrt(M_PI)*x) - gmx_erfd(y)/(x*y);
+    }
+    else
+    {
+        return -4/(3*sqrt(M_PI));
+    }
 }
 
 // The PME corrections will be added to ~1/r2, so absolute tolerance of EPS is fine.
@@ -515,6 +532,240 @@ TEST_F(SimdMathTest, gmxSimdPmecorrPotentialR)
     GMX_EXPECT_SIMD_FUNC_NEAR(ref_pmecorrV, gmx_simd_pmecorrV_r);
 }
 
+
+
+
+
+
+/*
+ * Functions that only target single accuracy, even for double SIMD data
+ */
+
+TEST_F(SimdMathTest, gmxSimdInvsqrtSingleaccuracyR)
+{
+    /* Increase the allowed error by the difference between the actual precision and single */
+    setUlpTol(ulpTol_ * (1LL << (std::numeric_limits<real>::digits-std::numeric_limits<float>::digits)));
+
+    setRange(1e-10, 1e10);
+    GMX_EXPECT_SIMD_FUNC_NEAR(ref_invsqrt, gmx_simd_invsqrt_singleaccuracy_r);
+}
+
+/*! \brief Function wrapper to return first result when testing \ref gmx_simd_invsqrt_pair_singleaccuracy_r */
+gmx_simd_real_t gmx_simdcall
+tst_invsqrt_singleaccuracy_pair0(gmx_simd_real_t x)
+{
+    gmx_simd_real_t r0, r1;
+    gmx_simd_invsqrt_pair_singleaccuracy_r(x, x, &r0, &r1);
+    return r0;
+}
+
+/*! \brief Function wrapper to return second result when testing \ref gmx_simd_invsqrt_pair_singleaccuracy_r */
+gmx_simd_real_t gmx_simdcall
+tst_invsqrt_singleaccuracy_pair1(gmx_simd_real_t x)
+{
+    gmx_simd_real_t r0, r1;
+    gmx_simd_invsqrt_pair_singleaccuracy_r(x, x, &r0, &r1);
+    return r1;
+}
+
+TEST_F(SimdMathTest, gmxSimdInvsqrtPairSingleaccuracyR)
+{
+    /* Increase the allowed error by the difference between the actual precision and single */
+    setUlpTol(ulpTol_ * (1LL << (std::numeric_limits<real>::digits-std::numeric_limits<float>::digits)));
+
+    setRange(1e-10, 1e10);
+    GMX_EXPECT_SIMD_FUNC_NEAR(ref_invsqrt, tst_invsqrt_singleaccuracy_pair0);
+    GMX_EXPECT_SIMD_FUNC_NEAR(ref_invsqrt, tst_invsqrt_singleaccuracy_pair1);
+}
+
+TEST_F(SimdMathTest, gmxSimdSqrtSingleaccuracyR)
+{
+    /* Increase the allowed error by the difference between the actual precision and single */
+    setUlpTol(ulpTol_ * (1LL << (std::numeric_limits<real>::digits-std::numeric_limits<float>::digits)));
+
+    // Just make sure sqrt(0)=0 works and isn't evaluated as 0*1/sqrt(0)=NaN
+    GMX_EXPECT_SIMD_REAL_NEAR(setSimdRealFrom3R(0, 2, 3), gmx_simd_sqrt_singleaccuracy_r(setSimdRealFrom3R(0, 4, 9)));
+}
+
+TEST_F(SimdMathTest, gmxSimdInvSingleaccuracyR)
+{
+    /* Increase the allowed error by the difference between the actual precision and single */
+    setUlpTol(ulpTol_ * (1LL << (std::numeric_limits<real>::digits-std::numeric_limits<float>::digits)));
+
+    // test <0
+    setRange(-1e10, -1e-10);
+    GMX_EXPECT_SIMD_FUNC_NEAR(ref_inv, gmx_simd_inv_singleaccuracy_r);
+    setRange(1e-10, 1e10);
+    GMX_EXPECT_SIMD_FUNC_NEAR(ref_inv, gmx_simd_inv_singleaccuracy_r);
+}
+
+TEST_F(SimdMathTest, gmxSimdLogSingleaccuracyR)
+{
+    /* Increase the allowed error by the difference between the actual precision and single */
+    setUlpTol(ulpTol_ * (1LL << (std::numeric_limits<real>::digits-std::numeric_limits<float>::digits)));
+
+    setRange(1e-30, 1e30);
+    GMX_EXPECT_SIMD_FUNC_NEAR(ref_log, gmx_simd_log_singleaccuracy_r);
+}
+
+// MSVC does not support exp2(), so we have no reference to test against
+#ifndef _MSC_VER
+TEST_F(SimdMathTest, gmxSimdExp2SingleaccuracyR)
+{
+    /* Increase the allowed error by the difference between the actual precision and single */
+    setUlpTol(ulpTol_ * (1LL << (std::numeric_limits<real>::digits-std::numeric_limits<float>::digits)));
+
+    setRange(-100, 100);
+    GMX_EXPECT_SIMD_FUNC_NEAR(ref_exp2, gmx_simd_exp2_singleaccuracy_r);
+}
+#endif
+
+TEST_F(SimdMathTest, gmxSimdExpSingleaccuracyR)
+{
+    /* Increase the allowed error by the difference between the actual precision and single */
+    setUlpTol(ulpTol_ * (1LL << (std::numeric_limits<real>::digits-std::numeric_limits<float>::digits)));
+
+    setRange(-75, 75);
+    GMX_EXPECT_SIMD_FUNC_NEAR(ref_exp, gmx_simd_exp_singleaccuracy_r);
+}
+
+TEST_F(SimdMathTest, gmxSimdErfSingleaccuracyR)
+{
+    /* Increase the allowed error by the difference between the actual precision and single */
+    setUlpTol(ulpTol_ * (1LL << (std::numeric_limits<real>::digits-std::numeric_limits<float>::digits)));
+
+    setRange(-9, 9);
+    setAbsTol(GMX_REAL_MIN);
+    GMX_EXPECT_SIMD_FUNC_NEAR(ref_erf, gmx_simd_erf_singleaccuracy_r);
+}
+
+TEST_F(SimdMathTest, gmxSimdErfcSingleaccuracyR)
+{
+    /* Increase the allowed error by the difference between the actual precision and single */
+    setUlpTol(ulpTol_ * (1LL << (std::numeric_limits<real>::digits-std::numeric_limits<float>::digits)));
+
+    setRange(-9, 9);
+    setAbsTol(GMX_REAL_MIN);
+    // Our erfc algorithm has 4 ulp accuracy, so relax tolerance a bit
+    setUlpTol(4*ulpTol_);
+    GMX_EXPECT_SIMD_FUNC_NEAR(ref_erfc, gmx_simd_erfc_singleaccuracy_r);
+}
+
+
+TEST_F(SimdMathTest, gmxSimdSinSingleaccuracyR)
+{
+    /* Increase the allowed error by the difference between the actual precision and single */
+    setUlpTol(ulpTol_ * (1LL << (std::numeric_limits<real>::digits-std::numeric_limits<float>::digits)));
+
+    setRange(-8*M_PI, 8*M_PI);
+    GMX_EXPECT_SIMD_FUNC_NEAR(ref_sin, gmx_simd_sin_singleaccuracy_r);
+    // Range reduction leads to accuracy loss, so we might want higher tolerance here
+    setRange(-10000, 10000);
+    setUlpTol(2*ulpTol_);
+    GMX_EXPECT_SIMD_FUNC_NEAR(ref_sin, gmx_simd_sin_singleaccuracy_r);
+}
+
+TEST_F(SimdMathTest, gmxSimdCosSingleaccuracyR)
+{
+    /* Increase the allowed error by the difference between the actual precision and single */
+    setUlpTol(ulpTol_ * (1LL << (std::numeric_limits<real>::digits-std::numeric_limits<float>::digits)));
+
+    setRange(-8*M_PI, 8*M_PI);
+    GMX_EXPECT_SIMD_FUNC_NEAR(ref_cos, gmx_simd_cos_singleaccuracy_r);
+    // Range reduction leads to accuracy loss, so we might want higher tolerance here
+    setRange(-10000, 10000);
+    GMX_EXPECT_SIMD_FUNC_NEAR(ref_cos, gmx_simd_cos_singleaccuracy_r);
+}
+
+TEST_F(SimdMathTest, gmxSimdTanSingleaccuracyR)
+{
+    /* Increase the allowed error by the difference between the actual precision and single */
+    setUlpTol(ulpTol_ * (1LL << (std::numeric_limits<real>::digits-std::numeric_limits<float>::digits)));
+
+    // Tan(x) is a little sensitive due to the division in the algorithm.
+    // Rather than using lots of extra FP operations, we accept the algorithm
+    // presently only achieves a ~3 ulp error and use the medium tolerance.
+    setRange(-8*M_PI, 8*M_PI);
+    GMX_EXPECT_SIMD_FUNC_NEAR(ref_tan, gmx_simd_tan_singleaccuracy_r);
+    // Range reduction leads to accuracy loss, so we might want higher tolerance here
+    setRange(-10000, 10000);
+    GMX_EXPECT_SIMD_FUNC_NEAR(ref_tan, gmx_simd_tan_singleaccuracy_r);
+}
+
+TEST_F(SimdMathTest, gmxSimdAsinSingleaccuracyR)
+{
+    /* Increase the allowed error by the difference between the actual precision and single */
+    setUlpTol(ulpTol_ * (1LL << (std::numeric_limits<real>::digits-std::numeric_limits<float>::digits)));
+
+    // Our present asin(x) algorithm achieves 2-3 ulp accuracy
+    setRange(-1, 1);
+    GMX_EXPECT_SIMD_FUNC_NEAR(ref_asin, gmx_simd_asin_singleaccuracy_r);
+}
+
+TEST_F(SimdMathTest, gmxSimdAcosSingleaccuracyR)
+{
+    /* Increase the allowed error by the difference between the actual precision and single */
+    setUlpTol(ulpTol_ * (1LL << (std::numeric_limits<real>::digits-std::numeric_limits<float>::digits)));
+
+    // Our present acos(x) algorithm achieves 2-3 ulp accuracy
+    setRange(-1, 1);
+    GMX_EXPECT_SIMD_FUNC_NEAR(ref_acos, gmx_simd_acos_singleaccuracy_r);
+}
+
+TEST_F(SimdMathTest, gmxSimdAtanSingleaccuracyR)
+{
+    /* Increase the allowed error by the difference between the actual precision and single */
+    setUlpTol(ulpTol_ * (1LL << (std::numeric_limits<real>::digits-std::numeric_limits<float>::digits)));
+
+    // Our present atan(x) algorithm achieves 1 ulp accuracy
+    setRange(-10000, 10000);
+    GMX_EXPECT_SIMD_FUNC_NEAR(ref_atan, gmx_simd_atan_singleaccuracy_r);
+}
+
+TEST_F(SimdMathTest, gmxSimdAtan2SingleaccuracyR)
+{
+    /* Increase the allowed error by the difference between the actual precision and single */
+    setUlpTol(ulpTol_ * (1LL << (std::numeric_limits<real>::digits-std::numeric_limits<float>::digits)));
+
+    // test each quadrant
+    GMX_EXPECT_SIMD_REAL_NEAR(setSimdRealFrom1R(atan2(1.0, 1.0)), gmx_simd_atan2_singleaccuracy_r(rSimd_1_2_3, rSimd_1_2_3));
+    GMX_EXPECT_SIMD_REAL_NEAR(setSimdRealFrom1R(atan2(-1.0, 1.0)), gmx_simd_atan2_singleaccuracy_r(rSimd_m1_m2_m3, rSimd_1_2_3));
+    GMX_EXPECT_SIMD_REAL_NEAR(setSimdRealFrom1R(atan2(-1.0, -1.0)), gmx_simd_atan2_singleaccuracy_r(rSimd_m1_m2_m3, rSimd_m1_m2_m3));
+    GMX_EXPECT_SIMD_REAL_NEAR(setSimdRealFrom1R(atan2(1.0, -1.0)), gmx_simd_atan2_singleaccuracy_r(rSimd_1_2_3, rSimd_m1_m2_m3));
+    // cases important for calculating angles
+    // values on coordinate axes
+    GMX_EXPECT_SIMD_REAL_NEAR(setSimdRealFrom1R(atan2(0.0, 1.0)), gmx_simd_atan2_singleaccuracy_r(gmx_simd_setzero_r(), rSimd_1_2_3));
+    GMX_EXPECT_SIMD_REAL_NEAR(setSimdRealFrom1R(atan2(1.0, 0.0)), gmx_simd_atan2_singleaccuracy_r(rSimd_1_2_3, gmx_simd_setzero_r()));
+    GMX_EXPECT_SIMD_REAL_NEAR(setSimdRealFrom1R(atan2(0.0, -1.0)), gmx_simd_atan2_singleaccuracy_r(gmx_simd_setzero_r(), rSimd_m1_m2_m3));
+    GMX_EXPECT_SIMD_REAL_NEAR(setSimdRealFrom1R(atan2(-1.0, 0.0)), gmx_simd_atan2_singleaccuracy_r(rSimd_m1_m2_m3, gmx_simd_setzero_r()));
+    // degenerate value (origin) should return 0.0
+    GMX_EXPECT_SIMD_REAL_NEAR(setSimdRealFrom1R(atan2(0.0, 0.0)), gmx_simd_atan2_singleaccuracy_r(setSimdRealFrom3R(0.0, 0.0, 0.0), gmx_simd_setzero_r()));
+}
+
+TEST_F(SimdMathTest, gmxSimdPmecorrForceSingleaccuracyR)
+{
+    // The PME corrections will be added to ~1/r2, so absolute tolerance of EPS is fine.
+    // Pme correction only needs to be ~1e-6 accuracy single.
+    // Then increase the allowed error by the difference between the actual precision and single.
+    setUlpTol( ((gmx_int64_t)(5e-6/GMX_FLOAT_EPS)) * (1LL << (std::numeric_limits<real>::digits-std::numeric_limits<float>::digits)));
+
+    setRange(0.15, 4);
+    setAbsTol(GMX_FLOAT_EPS);
+    GMX_EXPECT_SIMD_FUNC_NEAR(ref_pmecorrF, gmx_simd_pmecorrF_singleaccuracy_r);
+}
+
+TEST_F(SimdMathTest, gmxSimdPmecorrPotentialSingleaccuracyR)
+{
+    // The PME corrections will be added to ~1/r, so absolute tolerance of EPS is fine.
+    // Pme correction only needs to be ~1e-6 accuracy single.
+    // Then increase the allowed error by the difference between the actual precision and single.
+    setUlpTol( ((gmx_int64_t)(5e-6/GMX_FLOAT_EPS)) * (1LL << (std::numeric_limits<real>::digits-std::numeric_limits<float>::digits)));
+
+    setRange(0.15, 4);
+    setAbsTol(GMX_FLOAT_EPS);
+    GMX_EXPECT_SIMD_FUNC_NEAR(ref_pmecorrV, gmx_simd_pmecorrV_singleaccuracy_r);
+}
+
 }      // namespace
 
 #endif // GMX_SIMD_HAVE_REAL
