@@ -34,14 +34,15 @@
  * To help us fund GROMACS development, we humbly ask that you cite
  * the research papers on the package. Check out http://www.gromacs.org.
  */
+#include "gmxpre.h"
+
 #include "statistics.h"
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+
 #include <math.h>
-#include "typedefs.h"
+
+#include "gromacs/math/vec.h"
+#include "gromacs/utility/real.h"
 #include "gromacs/utility/smalloc.h"
-#include "vec.h"
 
 static int gmx_dnint(double x)
 {
