@@ -3,7 +3,7 @@
  *
  * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
  * Copyright (c) 2001-2008, The GROMACS development team.
- * Copyright (c) 2013,2014, by the GROMACS development team, led by
+ * Copyright (c) 2013,2014,2015, by the GROMACS development team, led by
  * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
  * and including many others, as listed in the AUTHORS file in the
  * top-level source directory and at http://www.gromacs.org.
@@ -34,21 +34,23 @@
  * To help us fund GROMACS development, we humbly ask that you cite
  * the research papers on the package. Check out http://www.gromacs.org.
  */
-#include "gromacs/timing/wallcycle.h"
+#include "gmxpre.h"
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "wallcycle.h"
 
-#include <string.h>
+#include "config.h"
 
-#include "gromacs/utility/smalloc.h"
-#include "gmx_fatal.h"
-#include "md_logging.h"
-#include "gromacs/utility/cstringutil.h"
+#include <assert.h>
+#include <stdlib.h>
 
+#include "gromacs/legacyheaders/md_logging.h"
+#include "gromacs/legacyheaders/types/commrec.h"
 #include "gromacs/timing/cyclecounter.h"
+#include "gromacs/timing/gpu_timing.h"
+#include "gromacs/utility/cstringutil.h"
 #include "gromacs/utility/gmxmpi.h"
+#include "gromacs/utility/smalloc.h"
+#include "gromacs/utility/snprintf.h"
 
 /* DEBUG_WCYCLE adds consistency checking for the counters.
  * It checks if you stop a counter different from the last
@@ -56,6 +58,10 @@
  */
 /* #define DEBUG_WCYCLE */
 
+#ifdef DEBUG_WCYCLE
+#include "gromacs/utility/fatalerror.h"
+#endif
+
 typedef struct
 {
     int          n;
@@ -67,6 +73,8 @@ typedef struct
 typedef struct gmx_wallcycle
 {
     wallcc_t        *wcc;
+    /* did we detect one or more invalid cycle counts */
+    gmx_bool         haveInvalidCount;
     /* variables for testing/debugging */
     gmx_bool         wc_barrier;
     wallcc_t        *wcc_all;
@@ -109,8 +117,14 @@ static const char *wcsn[ewcsNR] =
     "DD redist.", "DD NS grid + sort", "DD setup comm.",
     "DD make top.", "DD make constr.", "DD top. other",
     "NS grid local", "NS grid non-loc.", "NS search local", "NS search non-loc.",
-    "Bonded F", "Nonbonded F", "Ewald F correction",
-    "NB X buffer ops.", "NB F buffer ops."
+    "Bonded F",
+    "Bonded-FEP F",
+    "Restraints F",
+    "Listed buffer ops.",
+    "Nonbonded F",
+    "Ewald F correction",
+    "NB X buffer ops.",
+    "NB F buffer ops.",
 };
 
 gmx_bool wallcycle_have_counter(void)
@@ -131,6 +145,7 @@ gmx_wallcycle_t wallcycle_init(FILE *fplog, int resetstep, t_commrec gmx_unused
 
     snew(wc, 1);
 
+    wc->haveInvalidCount    = FALSE;
     wc->wc_barrier          = FALSE;
     wc->wcc_all             = NULL;
     wc->wc_depth            = 0;
@@ -309,9 +324,25 @@ double wallcycle_stop(gmx_wallcycle_t wc, int ewc)
     debug_stop_check(wc, ewc);
 #endif
 
-    cycle           = gmx_cycles_read();
-    last            = cycle - wc->wcc[ewc].start;
-    wc->wcc[ewc].c += last;
+    /* When processes or threads migrate between cores, the cycle counting
+     * can get messed up if the cycle counter on different cores are not
+     * synchronized. When this happens we expect both large negative and
+     * positive cycle differences. We can detect negative cycle differences.
+     * Detecting too large positive counts if difficult, since count can be
+     * large, especially for ewcRUN. If we detect a negative count,
+     * we will not print the cycle accounting table.
+     */
+    cycle                    = gmx_cycles_read();
+    if (cycle >= wc->wcc[ewc].start)
+    {
+        last                 = cycle - wc->wcc[ewc].start;
+    }
+    else
+    {
+        last                 = 0;
+        wc->haveInvalidCount = TRUE;
+    }
+    wc->wcc[ewc].c          += last;
     wc->wcc[ewc].n++;
     if (wc->wcc_all)
     {
@@ -329,6 +360,12 @@ double wallcycle_stop(gmx_wallcycle_t wc, int ewc)
     return last;
 }
 
+void wallcycle_get(gmx_wallcycle_t wc, int ewc, int *n, double *c)
+{
+    *n = wc->wcc[ewc].n;
+    *c = (double)wc->wcc[ewc].c;
+}
+
 void wallcycle_reset_all(gmx_wallcycle_t wc)
 {
     int i;
@@ -343,6 +380,8 @@ void wallcycle_reset_all(gmx_wallcycle_t wc)
         wc->wcc[i].n = 0;
         wc->wcc[i].c = 0;
     }
+    wc->haveInvalidCount = FALSE;
+
     if (wc->wcc_all)
     {
         for (i = 0; i < ewcNR*ewcNR; i++)
@@ -370,11 +409,28 @@ static gmx_bool is_pme_subcounter(int ewc)
     return (ewc >= ewcPME_REDISTXF && ewc < ewcPMEWAITCOMM);
 }
 
+/* Subtract counter ewc_sub timed inside a timing block for ewc_main */
+static void subtract_cycles(wallcc_t *wcc, int ewc_main, int ewc_sub)
+{
+    if (wcc[ewc_sub].n > 0)
+    {
+        if (wcc[ewc_main].c >= wcc[ewc_sub].c)
+        {
+            wcc[ewc_main].c -= wcc[ewc_sub].c;
+        }
+        else
+        {
+            /* Something is wrong with the cycle counting */
+            wcc[ewc_main].c  = 0;
+        }
+    }
+}
+
 void wallcycle_sum(t_commrec *cr, gmx_wallcycle_t wc)
 {
     wallcc_t *wcc;
     double    cycles[ewcNR+ewcsNR];
-    double    cycles_n[ewcNR+ewcsNR], buf[ewcNR+ewcsNR], *cyc_all, *buf_all;
+    double    cycles_n[ewcNR+ewcsNR+1], buf[ewcNR+ewcsNR+1], *cyc_all, *buf_all;
     int       i, j;
     int       nsum;
 
@@ -421,26 +477,15 @@ void wallcycle_sum(t_commrec *cr, gmx_wallcycle_t wc)
         }
     }
 
-    if (wcc[ewcDDCOMMLOAD].n > 0)
-    {
-        wcc[ewcDOMDEC].c -= wcc[ewcDDCOMMLOAD].c;
-    }
-    if (wcc[ewcDDCOMMBOUND].n > 0)
-    {
-        wcc[ewcDOMDEC].c -= wcc[ewcDDCOMMBOUND].c;
-    }
-    if (wcc[ewcPME_FFTCOMM].n > 0)
-    {
-        wcc[ewcPME_FFT].c -= wcc[ewcPME_FFTCOMM].c;
-    }
+    subtract_cycles(wcc, ewcDOMDEC, ewcDDCOMMLOAD);
+    subtract_cycles(wcc, ewcDOMDEC, ewcDDCOMMBOUND);
+
+    subtract_cycles(wcc, ewcPME_FFT, ewcPME_FFTCOMM);
 
     if (cr->npmenodes == 0)
     {
         /* All nodes do PME (or no PME at all) */
-        if (wcc[ewcPMEMESH].n > 0)
-        {
-            wcc[ewcFORCE].c -= wcc[ewcPMEMESH].c;
-        }
+        subtract_cycles(wcc, ewcFORCE, ewcPMEMESH);
     }
     else
     {
@@ -448,6 +493,7 @@ void wallcycle_sum(t_commrec *cr, gmx_wallcycle_t wc)
         if (wcc[ewcPMEMESH].n > 0)
         {
             /* This must be a PME only node, calculate the Wait + Comm. time */
+            assert(wcc[ewcRUN].c >= wcc[ewcPMEMESH].c);
             wcc[ewcPMEWAITCOMM].c = wcc[ewcRUN].c - wcc[ewcPMEMESH].c;
         }
     }
@@ -472,12 +518,14 @@ void wallcycle_sum(t_commrec *cr, gmx_wallcycle_t wc)
 #ifdef GMX_MPI
     if (cr->nnodes > 1)
     {
-        MPI_Allreduce(cycles_n, buf, nsum, MPI_DOUBLE, MPI_MAX,
+        cycles_n[nsum] = (wc->haveInvalidCount > 0 ? 1 : 0);
+        MPI_Allreduce(cycles_n, buf, nsum + 1, MPI_DOUBLE, MPI_MAX,
                       cr->mpi_comm_mysim);
         for (i = 0; i < ewcNR; i++)
         {
             wcc[i].n = (int)(buf[i] + 0.5);
         }
+        wc->haveInvalidCount = (buf[nsum] > 0);
 #ifdef GMX_CYCLE_SUBCOUNTERS
         for (i = 0; i < ewcsNR; i++)
         {
@@ -524,6 +572,7 @@ static void print_cycles(FILE *fplog, double c2t, const char *name,
     char   nthreads_str[6];
     char   ncalls_str[11];
     double wallt;
+    double percentage = (tot > 0.) ? (100. * c_sum / tot) : 0.;
 
     if (c_sum > 0)
     {
@@ -558,7 +607,7 @@ static void print_cycles(FILE *fplog, double c2t, const char *name,
 
         fprintf(fplog, " %-19.19s %4s %4s %10s  %10.3f %14.3f %5.1f\n",
                 name, nnodes_str, nthreads_str, ncalls_str, wallt,
-                c_sum*1e-9, 100*c_sum/tot);
+                c_sum*1e-9, percentage);
     }
 }
 
@@ -578,7 +627,7 @@ static void print_gputimes(FILE *fplog, const char *name,
         sprintf(num, "          ");
         sprintf(avg_perf, "          ");
     }
-    if (t != tot_t)
+    if (t != tot_t && tot_t > 0)
     {
         fprintf(fplog, " %-29s %10s%12.3f   %s   %5.1f\n",
                 name, num, t/1000, avg_perf, 100 * t/tot_t);
@@ -623,11 +672,11 @@ static void print_header(FILE *fplog, int nrank_pp, int nth_pp, int nrank_pme, i
 }
 
 void wallcycle_print(FILE *fplog, int nnodes, int npme, double realtime,
-                     gmx_wallcycle_t wc, wallclock_gpu_t *gpu_t)
+                     gmx_wallcycle_t wc, struct gmx_wallclock_gpu_t *gpu_t)
 {
     double     *cyc_sum;
     double      tot, tot_for_pp, tot_for_rest, tot_gpu, tot_cpu_overlap, gpu_cpu_ratio, tot_k;
-    double      c2t, c2t_pp, c2t_pme;
+    double      c2t, c2t_pp, c2t_pme = 0;
     int         i, j, npp, nth_pp, nth_pme, nth_tot;
     char        buf[STRLEN];
     const char *hline = "-----------------------------------------------------------------------------";
@@ -638,11 +687,19 @@ void wallcycle_print(FILE *fplog, int nnodes, int npme, double realtime,
     }
 
     nth_pp  = wc->nthreads_pp;
+    assert(nth_pp > 0);
+
     nth_pme = wc->nthreads_pme;
+    assert(nth_pme > 0);
 
     cyc_sum = wc->cycles_sum;
 
+    assert(nnodes > 0);
+    assert(npme >= 0);
     npp     = nnodes - npme;
+    /* npme is the number of PME-only ranks used, and we always do PP work */
+    assert(npp > 0);
+
     nth_tot = npp*nth_pp + npme*nth_pme;
 
     /* When using PME-only nodes, the next line is valid for both
@@ -651,17 +708,36 @@ void wallcycle_print(FILE *fplog, int nnodes, int npme, double realtime,
     tot        = cyc_sum[ewcRUN];
     tot_for_pp = 0;
 
+    if (tot <= 0.0)
+    {
+        /* TODO This is heavy handed, but until someone reworks the
+           code so that it is provably robust with respect to
+           non-positive values for all possible timer and cycle
+           counters, there is less value gained from printing whatever
+           timing data might still be sensible for some non-Jenkins
+           run, than is lost from diagnosing Jenkins FP exceptions on
+           runs about whose execution time we don't care. */
+        md_print_warn(NULL, fplog, "WARNING: A total of %f CPU cycles was recorded, so mdrun cannot print a time accounting\n", tot);
+        return;
+    }
+
+    if (wc->haveInvalidCount)
+    {
+        md_print_warn(NULL, fplog, "%s\n",
+                      "NOTE: Detected invalid cycle counts, probably because threads moved between CPU cores that do not have synchronized cycle counters. Will not print the cycle accounting.");
+        return;
+    }
+
+
     /* Conversion factor from cycles to seconds */
-    if (tot > 0)
+    c2t     = realtime/tot;
+    c2t_pp  = c2t * nth_tot / (double) (npp*nth_pp);
+    if (npme > 0)
     {
-        c2t     = realtime/tot;
-        c2t_pp  = c2t * nth_tot / (double) (npp*nth_pp);
         c2t_pme = c2t * nth_tot / (double) (npme*nth_pme);
     }
     else
     {
-        c2t     = 0;
-        c2t_pp  = 0;
         c2t_pme = 0;
     }
 
@@ -813,9 +889,12 @@ void wallcycle_print(FILE *fplog, int nnodes, int npme, double realtime,
         fprintf(fplog, "%s\n", hline);
 
         gpu_cpu_ratio = tot_gpu/tot_cpu_overlap;
-        fprintf(fplog, "\nForce evaluation time GPU/CPU: %.3f ms/%.3f ms = %.3f\n",
-                tot_gpu/gpu_t->nb_c, tot_cpu_overlap/wc->wcc[ewcFORCE].n,
-                gpu_cpu_ratio);
+        if (gpu_t->nb_c > 0 && wc->wcc[ewcFORCE].n > 0)
+        {
+            fprintf(fplog, "\nForce evaluation time GPU/CPU: %.3f ms/%.3f ms = %.3f\n",
+                    tot_gpu/gpu_t->nb_c, tot_cpu_overlap/wc->wcc[ewcFORCE].n,
+                    gpu_cpu_ratio);
+        }
 
         /* only print notes related to CPU-GPU load balance with PME */
         if (wc->wcc[ewcPMEMESH].n > 0)
@@ -859,6 +938,13 @@ void wallcycle_print(FILE *fplog, int nnodes, int npme, double realtime,
         }
     }
 
+    if (wc->wc_barrier)
+    {
+        md_print_warn(NULL, fplog,
+                      "MPI_Barrier was called before each cycle start/stop\n"
+                      "call, so timings are not those of real runs.\n");
+    }
+
     if (wc->wcc[ewcNB_XF_BUF_OPS].n > 0 &&
         (cyc_sum[ewcDOMDEC] > tot*0.1 ||
          cyc_sum[ewcNS] > tot*0.1))
@@ -922,6 +1008,17 @@ void wallcycle_sub_start(gmx_wallcycle_t wc, int ewcs)
     }
 }
 
+void wallcycle_sub_start_nocount(gmx_wallcycle_t wc, int ewcs)
+{
+    if (wc == NULL)
+    {
+        return;
+    }
+
+    wallcycle_sub_start(wc, ewcs);
+    wc->wcsc[ewcs].n--;
+}
+
 void wallcycle_sub_stop(gmx_wallcycle_t wc, int ewcs)
 {
     if (wc != NULL)
@@ -936,6 +1033,9 @@ void wallcycle_sub_stop(gmx_wallcycle_t wc, int ewcs)
 void wallcycle_sub_start(gmx_wallcycle_t gmx_unused wc, int gmx_unused ewcs)
 {
 }
+void wallcycle_sub_start_nocount(gmx_wallcycle_t gmx_unused wc, int gmx_unused ewcs)
+{
+}
 void wallcycle_sub_stop(gmx_wallcycle_t gmx_unused wc, int gmx_unused ewcs)
 {
 }
