@@ -39,21 +39,19 @@
  * \author Teemu Murtola <teemu.murtola@gmail.com>
  * \ingroup module_utility
  */
-#include "gromacs/utility/init.h"
+#include "gmxpre.h"
+
+#include "init.h"
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
-
-#include "gromacs/legacyheaders/gmx_fatal.h"
 
+#include "gromacs/utility/basedefinitions.h"
+#include "gromacs/utility/fatalerror.h"
+#include "gromacs/utility/gmxassert.h"
 #ifdef GMX_LIB_MPI
 #include "gromacs/utility/gmxmpi.h"
 #endif
 
-#include "gromacs/utility/common.h"
-#include "gromacs/utility/gmxassert.h"
-
 namespace gmx
 {
 
