@@ -34,23 +34,22 @@
  * To help us fund GROMACS development, we humbly ask that you cite
  * the research papers on the package. Check out http://www.gromacs.org.
  */
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "gmxpre.h"
 
 #include <math.h>
-#include "sysstuff.h"
+#include <stdlib.h>
 #include <string.h>
-#include "gromacs/utility/smalloc.h"
-#include "macros.h"
-#include "xutil.h"
-#include "buttons.h"
-#include "manager.h"
-#include "nmol.h"
-#include "nleg.h"
 
 #include "gromacs/fileio/writeps.h"
-#include "gromacs/math/3dview.h"
+#include "gromacs/legacyheaders/macros.h"
+#include "gromacs/utility/smalloc.h"
+
+#include "3dview.h"
+#include "buttons.h"
+#include "manager.h"
+#include "nleg.h"
+#include "nmol.h"
+#include "xutil.h"
 
 #define MSIZE 4
 
@@ -196,7 +195,7 @@ static void draw_box(t_psdata ps, t_3dview *view, matrix box,
         {
             corner[i][j] = ivec[i][j]*box[j][j];
         }
-        m4_op(view->proj, corner[i], x4);
+        gmx_mat4_transform_point(view->proj, corner[i], x4);
         v4_to_iv2(x4, vec2[i], x0, y0, sx, sy);
     }
     ps_color(ps, 0, 0, 0.5);
@@ -240,7 +239,7 @@ void ps_draw_mol(t_psdata ps, t_manager *man)
     {
         if (man->bVis[i])
         {
-            m4_op(view->proj, man->x[i], x4);
+            gmx_mat4_transform_point(view->proj, man->x[i], x4);
             man->zz[i] = x4[ZZ];
             v4_to_iv2(x4, vec2[i], x0, y0, sx, sy);
         }
